@@ -1,7 +1,7 @@
 /*
  * libosinfo:
  *
- * Copyright (C) 2009-2012, 2014 Red Hat, Inc.
+ * Copyright (C) 2009-2020 Red Hat, Inc.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -16,10 +16,6 @@
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library. If not, see
  * <http://www.gnu.org/licenses/>.
- *
- * Authors:
- *   Arjun Roy <arroy@redhat.com>
- *   Daniel P. Berrange <berrange@redhat.com>
  */
 
 #include <osinfo/osinfo.h>
@@ -28,10 +24,6 @@
 #include <string.h>
 #include <glib/gi18n-lib.h>
 
-G_DEFINE_TYPE(OsinfoDb, osinfo_db, G_TYPE_OBJECT);
-
-#define OSINFO_DB_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE((obj), OSINFO_TYPE_DB, OsinfoDbPrivate))
-
 #define match_regex(pattern, str)                                       \
     (((pattern) == NULL) ||                                             \
      (((str) != NULL) &&                                                \
@@ -137,7 +129,7 @@ struct _OsinfoDbPrivate
     OsinfoInstallScriptList *scripts;
 };
 
-static void osinfo_db_finalize(GObject *object);
+G_DEFINE_TYPE_WITH_PRIVATE(OsinfoDb, osinfo_db, G_TYPE_OBJECT);
 
 static void
 osinfo_db_finalize(GObject *object)
@@ -163,15 +155,13 @@ osinfo_db_class_init(OsinfoDbClass *klass)
     GObjectClass *g_klass = G_OBJECT_CLASS(klass);
 
     g_klass->finalize = osinfo_db_finalize;
-
-    g_type_class_add_private(klass, sizeof(OsinfoDbPrivate));
 }
 
 
 static void
 osinfo_db_init(OsinfoDb *db)
 {
-    db->priv = OSINFO_DB_GET_PRIVATE(db);
+    db->priv = osinfo_db_get_instance_private(db);
     db->priv->devices = osinfo_devicelist_new();
     db->priv->platforms = osinfo_platformlist_new();
     db->priv->oses = osinfo_oslist_new();
@@ -180,9 +170,6 @@ osinfo_db_init(OsinfoDb *db)
     db->priv->scripts = osinfo_install_scriptlist_new();
 }
 
-/** PUBLIC METHODS */
-
-
 /**
  * osinfo_db_new:
  *
@@ -303,12 +290,15 @@ OsinfoDeployment *osinfo_db_find_deployment(OsinfoDb *db,
                                             OsinfoOs *os,
                                             OsinfoPlatform *platform)
 {
+    GList *deployments;
+    GList *tmp;
+
     g_return_val_if_fail(OSINFO_IS_DB(db), NULL);
     g_return_val_if_fail(OSINFO_IS_OS(os), NULL);
     g_return_val_if_fail(OSINFO_IS_PLATFORM(platform), NULL);
 
-    GList *deployments = osinfo_list_get_elements(OSINFO_LIST(db->priv->deployments));
-    GList *tmp = deployments;
+    deployments = osinfo_list_get_elements(OSINFO_LIST(db->priv->deployments));
+    tmp = deployments;
 
     while (tmp) {
         OsinfoDeployment *deployment = OSINFO_DEPLOYMENT(tmp->data);
@@ -529,8 +519,8 @@ void osinfo_db_add_install_script(OsinfoDb *db, OsinfoInstallScript *script)
 
 static gint media_volume_compare(gconstpointer a, gconstpointer b)
 {
-    OsinfoMedia *media_a = OSINFO_MEDIA(a);
-    OsinfoMedia *media_b = OSINFO_MEDIA(b);
+    OsinfoMedia *media_a = OSINFO_MEDIA((gpointer) a);
+    OsinfoMedia *media_b = OSINFO_MEDIA((gpointer) b);
     const gchar *volume_a = osinfo_media_get_volume_id(media_a);
     const gchar *volume_b = osinfo_media_get_volume_id(media_b);
 
@@ -576,6 +566,7 @@ static gboolean compare_media(OsinfoMedia *media,
 
     for (os_iter = oss; os_iter; os_iter = os_iter->next) {
         OsinfoOs *os = OSINFO_OS(os_iter->data);
+        OsinfoReleaseStatus release_status = osinfo_os_get_release_status(os);
         OsinfoMediaList *media_list = osinfo_os_get_media_list(os);
         GList *medias = osinfo_list_get_elements(OSINFO_LIST(media_list));
         GList *media_iter;
@@ -603,6 +594,11 @@ static gboolean compare_media(OsinfoMedia *media,
                     *fallback_oss = g_list_prepend(*fallback_oss, os);
                     continue;
                 }
+
+                if (release_status == OSINFO_RELEASE_STATUS_ROLLING) {
+                    *fallback_oss = g_list_prepend(*fallback_oss, os);
+                    continue;
+                }
             }
 
             if (os_vol_size <= 0)
@@ -1165,11 +1161,18 @@ static void __osinfoAddProductIfRelationship(gpointer data, gpointer opaque)
  */
 OsinfoOsList *osinfo_db_unique_values_for_os_relationship(OsinfoDb *db, OsinfoProductRelationship relshp)
 {
+    OsinfoOsList *newList;
+    struct __osinfoProductCheckRelationshipArgs args;
+    GList *entities;
+
     g_return_val_if_fail(OSINFO_IS_DB(db), NULL);
 
-    OsinfoOsList *newList = osinfo_oslist_new();
-    struct __osinfoProductCheckRelationshipArgs args = {OSINFO_LIST(newList), relshp};
-    GList *entities = osinfo_list_get_elements(OSINFO_LIST(db->priv->oses));
+    newList = osinfo_oslist_new();
+
+    args.list = OSINFO_LIST(newList);
+    args.relshp = relshp;
+
+    entities = osinfo_list_get_elements(OSINFO_LIST(db->priv->oses));
 
     g_list_foreach(entities, __osinfoAddProductIfRelationship, &args);
     g_list_free(entities);
@@ -1190,11 +1193,18 @@ OsinfoOsList *osinfo_db_unique_values_for_os_relationship(OsinfoDb *db, OsinfoPr
  */
 OsinfoPlatformList *osinfo_db_unique_values_for_platform_relationship(OsinfoDb *db, OsinfoProductRelationship relshp)
 {
+    OsinfoPlatformList *newList;
+    struct __osinfoProductCheckRelationshipArgs args;
+    GList *entities;
+
     g_return_val_if_fail(OSINFO_IS_DB(db), NULL);
 
-    OsinfoPlatformList *newList = osinfo_platformlist_new();
-    struct __osinfoProductCheckRelationshipArgs args = {OSINFO_LIST(newList), relshp};
-    GList *entities = osinfo_list_get_elements(OSINFO_LIST(db->priv->platforms));
+    newList = osinfo_platformlist_new();
+
+    args.list = OSINFO_LIST(newList);
+    args.relshp = relshp;
+
+    entities = osinfo_list_get_elements(OSINFO_LIST(db->priv->platforms));
 
     g_list_foreach(entities, __osinfoAddProductIfRelationship, &args);
     g_list_free(entities);
