@@ -1,7 +1,7 @@
 /*
  * libosinfo:
  *
- * Copyright (C) 2009-2012, 2014 Red Hat, Inc.
+ * Copyright (C) 2009-2020 Red Hat, Inc.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -16,18 +16,11 @@
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library. If not, see
  * <http://www.gnu.org/licenses/>.
- *
- * Authors:
- *   Daniel P. Berrange <berrange@redhat.com>
  */
 
 #include <osinfo/osinfo.h>
 #include <glib/gi18n-lib.h>
 
-G_DEFINE_TYPE(OsinfoInstallConfig, osinfo_install_config, OSINFO_TYPE_ENTITY);
-
-#define OSINFO_INSTALL_CONFIG_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE((obj), OSINFO_TYPE_INSTALL_CONFIG, OsinfoInstallConfigPrivate))
-
 /**
  * SECTION:osinfo_install_config
  * @short_description: OS install configuration
@@ -43,12 +36,12 @@ struct _OsinfoInstallConfigPrivate
     gboolean unused;
 };
 
+G_DEFINE_TYPE_WITH_PRIVATE(OsinfoInstallConfig, osinfo_install_config, OSINFO_TYPE_ENTITY);
 
 /* Init functions */
 static void
 osinfo_install_config_class_init(OsinfoInstallConfigClass *klass)
 {
-    g_type_class_add_private(klass, sizeof(OsinfoInstallConfigPrivate));
 }
 
 static const gchar valid[] = {
@@ -68,7 +61,7 @@ osinfo_install_config_init(OsinfoInstallConfig *config)
     gchar pass[9];
     gsize i;
 
-    config->priv = OSINFO_INSTALL_CONFIG_GET_PRIVATE(config);
+    config->priv = osinfo_install_config_get_instance_private(config);
 
     osinfo_entity_set_param(OSINFO_ENTITY(config),
                             OSINFO_INSTALL_CONFIG_PROP_L10N_KEYBOARD,
@@ -228,20 +221,20 @@ const gchar *osinfo_install_config_get_l10n_language(OsinfoInstallConfig *config
 /**
  * osinfo_install_config_set_l10n_timezone:
  * @config: the install config.
- * @tz: the timezone
+ * @timezone: the timezone
  *
- * Set the #OSINFO_INSTALL_CONFIG_PROP_L10B_TIMEZONE parameter.
+ * Set the #OSINFO_INSTALL_CONFIG_PROP_L10N_TIMEZONE parameter.
  *
  * The expected format of this string is the tzdata names standard.
  *
  * Since: 0.2.0
  */
 void osinfo_install_config_set_l10n_timezone(OsinfoInstallConfig *config,
-                                             const gchar *tz)
+                                             const gchar *timezone)
 {
     osinfo_entity_set_param(OSINFO_ENTITY(config),
                             OSINFO_INSTALL_CONFIG_PROP_L10N_TIMEZONE,
-                            tz);
+                            timezone);
 }
 
 
@@ -771,6 +764,8 @@ const gchar *osinfo_install_config_get_avatar_disk(OsinfoInstallConfig *config)
  *
  * NOTE: Microsoft Windows XP requires pre-installation driver files to be
  * present in the script disk under the toplevel directory.
+ *
+ * Since: 0.2.2
  */
 void osinfo_install_config_set_pre_install_drivers_disk(OsinfoInstallConfig *config,
                                                         const gchar *disk)
