@@ -1,7 +1,7 @@
 /*
  * libosinfo:
  *
- * Copyright (C) 2009-2012, 2014 Red Hat, Inc.
+ * Copyright (C) 2009-2020 Red Hat, Inc.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -16,9 +16,6 @@
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library. If not, see
  * <http://www.gnu.org/licenses/>.
- *
- * Authors:
- *   Daniel P. Berrange <berrange@redhat.com>
  */
 
 #include <osinfo/osinfo.h>
@@ -30,10 +27,6 @@
 #include <glib/gi18n-lib.h>
 #include "osinfo_install_script_private.h"
 
-G_DEFINE_TYPE(OsinfoInstallScript, osinfo_install_script, OSINFO_TYPE_ENTITY);
-
-#define OSINFO_INSTALL_SCRIPT_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE((obj), OSINFO_TYPE_INSTALL_SCRIPT, OsinfoInstallScriptPrivate))
-
 /**
  * SECTION:osinfo_install_script
  * @short_description: OS install script generation
@@ -53,6 +46,8 @@ struct _OsinfoInstallScriptPrivate
     OsinfoAvatarFormat *avatar;
 };
 
+G_DEFINE_TYPE_WITH_PRIVATE(OsinfoInstallScript, osinfo_install_script, OSINFO_TYPE_ENTITY);
+
 enum {
     PROP_0,
 
@@ -63,8 +58,11 @@ enum {
     PROP_PATH_FORMAT,
     PROP_AVATAR_FORMAT,
     PROP_PREFERRED_INJECTION_METHOD,
-    PROP_INSTALLATION_SOURCE
+    PROP_INSTALLATION_SOURCE,
+
+    LAST_PROP
 };
+static GParamSpec *properties[LAST_PROP];
 
 typedef struct _OsinfoInstallScriptGenerateData OsinfoInstallScriptGenerateData;
 typedef struct _OsinfoInstallScriptGenerateOutputData OsinfoInstallScriptGenerateOutputData;
@@ -201,103 +199,78 @@ static void
 osinfo_install_script_class_init(OsinfoInstallScriptClass *klass)
 {
     GObjectClass *g_klass = G_OBJECT_CLASS(klass);
-    GParamSpec *pspec;
 
     g_klass->get_property = osinfo_install_script_get_property;
     g_klass->set_property = osinfo_install_script_set_property;
     g_klass->finalize = osinfo_install_script_finalize;
 
-    pspec = g_param_spec_string("template-uri",
-                                "TemplateURI",
-                                _("URI for install script template"),
-                                NULL /* default value */,
-                                G_PARAM_READABLE |
-                                G_PARAM_WRITABLE |
-                                G_PARAM_CONSTRUCT_ONLY |
-                                G_PARAM_STATIC_STRINGS);
-    g_object_class_install_property(g_klass,
-                                    PROP_TEMPLATE_URI,
-                                    pspec);
+    properties[PROP_TEMPLATE_URI] = g_param_spec_string("template-uri",
+                                                        "TemplateURI",
+                                                        _("URI for install script template"),
+                                                        NULL /* default value */,
+                                                        G_PARAM_READABLE |
+                                                        G_PARAM_WRITABLE |
+                                                        G_PARAM_CONSTRUCT_ONLY |
+                                                        G_PARAM_STATIC_STRINGS);
 
-    pspec = g_param_spec_string("template-data",
-                                "TemplateData",
-                                _("Data for install script template"),
-                                NULL /* default value */,
-                                G_PARAM_READABLE |
-                                G_PARAM_WRITABLE |
-                                G_PARAM_CONSTRUCT_ONLY |
-                                G_PARAM_STATIC_STRINGS);
-    g_object_class_install_property(g_klass,
-                                    PROP_TEMPLATE_DATA,
-                                    pspec);
+    properties[PROP_TEMPLATE_DATA] = g_param_spec_string("template-data",
+                                                         "TemplateData",
+                                                         _("Data for install script template"),
+                                                         NULL /* default value */,
+                                                         G_PARAM_READABLE |
+                                                         G_PARAM_WRITABLE |
+                                                         G_PARAM_CONSTRUCT_ONLY |
+                                                         G_PARAM_STATIC_STRINGS);
 
-    pspec = g_param_spec_string("profile",
-                                "Profile",
-                                _("Install script profile name"),
-                                NULL /* default value */,
-                                G_PARAM_READABLE |
-                                G_PARAM_WRITABLE |
-                                G_PARAM_CONSTRUCT_ONLY |
-                                G_PARAM_STATIC_STRINGS);
-    g_object_class_install_property(g_klass,
-                                    PROP_PROFILE,
-                                    pspec);
+    properties[PROP_PROFILE] = g_param_spec_string("profile",
+                                                   "Profile",
+                                                   _("Install script profile name"),
+                                                   NULL /* default value */,
+                                                   G_PARAM_READABLE |
+                                                   G_PARAM_WRITABLE |
+                                                   G_PARAM_CONSTRUCT_ONLY |
+                                                   G_PARAM_STATIC_STRINGS);
 
-    pspec = g_param_spec_string("product-key-format",
-                                "Product Key Format",
-                                _("Product key format mask"),
-                                NULL /* default value */,
-                                G_PARAM_READABLE |
-                                G_PARAM_STATIC_STRINGS);
-    g_object_class_install_property(g_klass,
-                                    PROP_PRODUCT_KEY_FORMAT,
-                                    pspec);
+    properties[PROP_PRODUCT_KEY_FORMAT] = g_param_spec_string("product-key-format",
+                                                              "Product Key Format",
+                                                              _("Product key format mask"),
+                                                              NULL /* default value */,
+                                                              G_PARAM_READABLE |
+                                                              G_PARAM_STATIC_STRINGS);
 
-    pspec = g_param_spec_enum("path-format",
-                              "Path Format",
-                              _("Expected path format"),
-                              OSINFO_TYPE_PATH_FORMAT,
-                              OSINFO_PATH_FORMAT_UNIX /* default value */,
-                              G_PARAM_READABLE |
-                              G_PARAM_STATIC_STRINGS);
-    g_object_class_install_property(g_klass,
-                                    PROP_PATH_FORMAT,
-                                    pspec);
+    properties[PROP_PATH_FORMAT] = g_param_spec_enum("path-format",
+                                                     "Path Format",
+                                                     _("Expected path format"),
+                                                     OSINFO_TYPE_PATH_FORMAT,
+                                                     OSINFO_PATH_FORMAT_UNIX /* default value */,
+                                                     G_PARAM_READABLE |
+                                                     G_PARAM_STATIC_STRINGS);
 
-    pspec = g_param_spec_object("avatar-format",
-                                "Avatar Format",
-                                _("Expected avatar format"),
-                                OSINFO_TYPE_AVATAR_FORMAT,
-                                G_PARAM_READABLE |
-                                G_PARAM_STATIC_STRINGS);
-    g_object_class_install_property(g_klass,
-                                    PROP_AVATAR_FORMAT,
-                                    pspec);
+    properties[PROP_AVATAR_FORMAT] = g_param_spec_object("avatar-format",
+                                                         "Avatar Format",
+                                                         _("Expected avatar format"),
+                                                         OSINFO_TYPE_AVATAR_FORMAT,
+                                                         G_PARAM_READABLE |
+                                                         G_PARAM_STATIC_STRINGS);
 
-    pspec = g_param_spec_flags("preferred-injection-method",
-                               "Preferred Injection Method",
-                               _("The preferred injection method"),
-                               OSINFO_TYPE_INSTALL_SCRIPT_INJECTION_METHOD,
-                               OSINFO_INSTALL_SCRIPT_INJECTION_METHOD_DISK, /* default value */
-                               G_PARAM_READABLE |
-                               G_PARAM_WRITABLE |
-                               G_PARAM_STATIC_STRINGS);
-    g_object_class_install_property(g_klass,
-                                    PROP_PREFERRED_INJECTION_METHOD,
-                                    pspec);
+    properties[PROP_PREFERRED_INJECTION_METHOD] = g_param_spec_flags("preferred-injection-method",
+                                                                     "Preferred Injection Method",
+                                                                     _("The preferred injection method"),
+                                                                     OSINFO_TYPE_INSTALL_SCRIPT_INJECTION_METHOD,
+                                                                     OSINFO_INSTALL_SCRIPT_INJECTION_METHOD_DISK, /* default value */
+                                                                     G_PARAM_READABLE |
+                                                                     G_PARAM_WRITABLE |
+                                                                     G_PARAM_STATIC_STRINGS);
 
-    pspec = g_param_spec_enum("installation-source",
-                              "Installation Source",
-                              _("The installation source to be used"),
-                              OSINFO_TYPE_INSTALL_SCRIPT_INSTALLATION_SOURCE,
-                              OSINFO_INSTALL_SCRIPT_INSTALLATION_SOURCE_MEDIA,
-                              G_PARAM_READABLE |
-                              G_PARAM_STATIC_STRINGS);
-    g_object_class_install_property(g_klass,
-                                    PROP_INSTALLATION_SOURCE,
-                                    pspec);
+    properties[PROP_INSTALLATION_SOURCE] = g_param_spec_enum("installation-source",
+                                                             "Installation Source",
+                                                             _("The installation source to be used"),
+                                                             OSINFO_TYPE_INSTALL_SCRIPT_INSTALLATION_SOURCE,
+                                                             OSINFO_INSTALL_SCRIPT_INSTALLATION_SOURCE_MEDIA,
+                                                             G_PARAM_READABLE |
+                                                             G_PARAM_STATIC_STRINGS);
 
-    g_type_class_add_private(klass, sizeof(OsinfoInstallScriptPrivate));
+    g_object_class_install_properties(g_klass, LAST_PROP, properties);
 }
 
 void osinfo_install_script_add_config_param(OsinfoInstallScript *script, OsinfoInstallConfigParam *param)
@@ -405,7 +378,7 @@ osinfo_install_script_get_config_param(OsinfoInstallScript *script,
 static void
 osinfo_install_script_init(OsinfoInstallScript *list)
 {
-    list->priv = OSINFO_INSTALL_SCRIPT_GET_PRIVATE(list);
+    list->priv = osinfo_install_script_get_instance_private(list);
     list->priv->config_params = osinfo_install_config_paramlist_new();
 }
 
@@ -2100,6 +2073,8 @@ gchar *osinfo_install_script_generate_command_line_for_media(OsinfoInstallScript
  * #osinfo_db_identify_tree() before calling this function.
  *
  * Returns: (transfer full): The generated command line string, NULL otherwise.
+ *
+ * Since: 1.6.0
  */
 gchar *osinfo_install_script_generate_command_line_for_tree(OsinfoInstallScript *script,
                                                             OsinfoTree *tree,
