@@ -1,7 +1,7 @@
 /*
  * libosinfo:
  *
- * Copyright (C) 2009-2015 Red Hat, Inc.
+ * Copyright (C) 2009-2020 Red Hat, Inc.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -16,10 +16,6 @@
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library. If not, see
  * <http://www.gnu.org/licenses/>.
- *
- * Authors:
- *   Arjun Roy <arroy@redhat.com>
- *   Daniel P. Berrange <berrange@redhat.com>
  */
 
 #include <glib/gi18n-lib.h>
@@ -46,10 +42,6 @@
 # define PCI_IDS PKG_DATA_DIR "/pci.ids"
 #endif
 
-G_DEFINE_TYPE(OsinfoLoader, osinfo_loader, G_TYPE_OBJECT);
-
-#define OSINFO_LOADER_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE((obj), OSINFO_TYPE_LOADER, OsinfoLoaderPrivate))
-
 /**
  * SECTION:osinfo_loader
  * @short_description: An database loader
@@ -67,6 +59,8 @@ struct _OsinfoLoaderPrivate
     GHashTable *entity_refs;
 };
 
+G_DEFINE_TYPE_WITH_PRIVATE(OsinfoLoader, osinfo_loader, G_TYPE_OBJECT);
+
 struct _OsinfoEntityKey
 {
     const char *name;
@@ -105,8 +99,6 @@ osinfo_loader_class_init(OsinfoLoaderClass *klass)
     bind_textdomain_codeset(GETTEXT_PACKAGE, "UTF-8");
 
     g_klass->finalize = osinfo_loader_finalize;
-
-    g_type_class_add_private(klass, sizeof(OsinfoLoaderPrivate));
 }
 
 
@@ -118,7 +110,7 @@ static void xpath_cache_value_free(gpointer values)
 static void
 osinfo_loader_init(OsinfoLoader *loader)
 {
-    loader->priv = OSINFO_LOADER_GET_PRIVATE(loader);
+    loader->priv = osinfo_loader_get_instance_private(loader);
     loader->priv->db = osinfo_db_new();
     loader->priv->xpath_cache = g_hash_table_new_full(g_str_hash,
                                                       g_str_equal,
@@ -130,7 +122,26 @@ osinfo_loader_init(OsinfoLoader *loader)
                                                       NULL);
 }
 
-/** PUBLIC METHODS */
+static gchar *
+osinfo_build_internal_id(const gchar *relpath,
+                         const gchar *id,
+                         gint number)
+{
+    gchar *driver_id = NULL;
+    g_autofree gchar *dirname = NULL;
+
+    dirname = g_path_get_dirname(relpath);
+    if (g_str_has_suffix(dirname, ".d")) {
+        g_autofree gchar *basename = NULL;
+
+        basename = g_path_get_basename(relpath);
+        driver_id = g_strdup_printf("%s:%s:%u", id, basename, number);
+    } else {
+        driver_id = g_strdup_printf("%s:%u", id, number);
+    }
+
+    return driver_id;
+}
 
 /**
  * osinfo_loader_new:
@@ -316,12 +327,13 @@ osinfo_loader_doc(const char *xpath,
     xmlNodePtr relnode;
     gchar *ret;
     xmlBufferPtr buf;
+    xmlXPathCompExprPtr comp;
 
     g_return_val_if_fail(ctxt != NULL, NULL);
     g_return_val_if_fail(xpath != NULL, NULL);
     g_return_val_if_fail(loader != NULL, NULL);
 
-    xmlXPathCompExprPtr comp = osinfo_loader_get_comp_xpath(loader, xpath);
+    comp = osinfo_loader_get_comp_xpath(loader, xpath);
 
     relnode = ctxt->node;
     obj = xmlXPathCompiledEval(comp, ctxt);
@@ -356,6 +368,8 @@ static void osinfo_loader_entity(OsinfoLoader *loader,
 {
     int i = 0;
     const gchar * const *langs = g_get_language_names();
+    xmlNodePtr *custom = NULL;
+    int ncustom;
 
     /* Standard well-known keys first, allow single value only */
     for (i = 0; keys != NULL && keys[i].name != NULL; i++) {
@@ -424,9 +438,8 @@ static void osinfo_loader_entity(OsinfoLoader *loader,
     }
 
     /* Then any site specific custom keys. x-... Can be repeated */
-    xmlNodePtr *custom = NULL;
-    int ncustom = osinfo_loader_nodeset("./*[substring(name(),1,2)='x-']",
-                                        loader, ctxt, &custom, err);
+    ncustom = osinfo_loader_nodeset("./*[substring(name(),1,2)='x-']",
+                                    loader, ctxt, &custom, err);
     if (error_is_set(err))
         return;
 
@@ -575,6 +588,7 @@ static void osinfo_loader_device(OsinfoLoader *loader,
                                  xmlNodePtr root,
                                  GError **err)
 {
+    OsinfoDevice *device;
     gchar *id = (gchar *)xmlGetProp(root, BAD_CAST "id");
     const OsinfoEntityKey keys[] = {
         { OSINFO_DEVICE_PROP_VENDOR, G_TYPE_STRING },
@@ -596,7 +610,7 @@ static void osinfo_loader_device(OsinfoLoader *loader,
         return;
     }
 
-    OsinfoDevice *device = osinfo_loader_get_device(loader, id);
+    device = osinfo_loader_get_device(loader, id);
     g_hash_table_remove(loader->priv->entity_refs, id);
     xmlFree(id);
 
@@ -617,19 +631,22 @@ static void osinfo_loader_device_link(OsinfoLoader *loader,
         return;
 
     for (i = 0; i < nrelated; i++) {
+        OsinfoDevice *dev;
+        OsinfoDeviceLink *devlink = NULL;
         const OsinfoEntityKey keys[] = {
             { OSINFO_DEVICELINK_PROP_DRIVER, G_TYPE_STRING },
             { NULL, G_TYPE_INVALID }
         };
         gchar *id = (gchar *)xmlGetProp(related[i], BAD_CAST "id");
+        gchar *supported;
+        xmlNodePtr saved;
         if (!id) {
             OSINFO_LOADER_SET_ERROR(err, _("Missing device link id property"));
             goto cleanup;
         }
-        OsinfoDevice *dev = osinfo_loader_get_device(loader, id);
+        dev = osinfo_loader_get_device(loader, id);
         xmlFree(id);
 
-        OsinfoDeviceLink *devlink = NULL;
         if (OSINFO_IS_PLATFORM(entity)) {
             devlink = osinfo_platform_add_device(OSINFO_PLATFORM(entity), dev);
         } else if (OSINFO_IS_OS(entity)) {
@@ -638,7 +655,7 @@ static void osinfo_loader_device_link(OsinfoLoader *loader,
             devlink = osinfo_deployment_add_device(OSINFO_DEPLOYMENT(entity), dev);
         }
 
-        gchar *supported = (gchar *)xmlGetProp(related[i],
+        supported = (gchar *)xmlGetProp(related[i],
                                                BAD_CAST OSINFO_DEVICELINK_PROP_SUPPORTED);
         if (supported != NULL) {
             osinfo_entity_set_param_boolean(OSINFO_ENTITY(devlink),
@@ -647,7 +664,7 @@ static void osinfo_loader_device_link(OsinfoLoader *loader,
             xmlFree(supported);
         }
 
-        xmlNodePtr saved = ctxt->node;
+        saved = ctxt->node;
         ctxt->node = related[i];
         osinfo_loader_entity(loader, OSINFO_ENTITY(devlink), keys, ctxt, root, err);
         ctxt->node = saved;
@@ -674,18 +691,20 @@ static void osinfo_loader_product_relshp(OsinfoLoader *loader,
         return;
 
     for (it = root->children; it; it = it->next) {
+        gchar *id;
+        OsinfoProduct *relproduct;
+
         if (it->type != XML_ELEMENT_NODE)
             continue;
 
         if (!xmlStrEqual(it->name, BAD_CAST name))
             continue;
 
-        gchar *id = (gchar *) xmlGetProp(it, BAD_CAST "id");
+        id = (gchar *) xmlGetProp(it, BAD_CAST "id");
         if (!id) {
             OSINFO_LOADER_SET_ERROR(err, _("Missing product upgrades id property"));
             goto cleanup;
         }
-        OsinfoProduct *relproduct;
         if (OSINFO_IS_PLATFORM(product))
             relproduct = OSINFO_PRODUCT(osinfo_loader_get_platform(loader, id));
         else
@@ -764,6 +783,7 @@ static void osinfo_loader_platform(OsinfoLoader *loader,
                                    xmlNodePtr root,
                                    GError **err)
 {
+    OsinfoPlatform *platform;
     gchar *id = (gchar *)xmlGetProp(root, BAD_CAST "id");
     if (!id) {
         OSINFO_LOADER_SET_ERROR(err, _("Missing platform id property"));
@@ -774,7 +794,7 @@ static void osinfo_loader_platform(OsinfoLoader *loader,
         return;
     }
 
-    OsinfoPlatform *platform = osinfo_loader_get_platform(loader, id);
+    platform = osinfo_loader_get_platform(loader, id);
     g_hash_table_remove(loader->priv->entity_refs, id);
     xmlFree(id);
 
@@ -798,6 +818,11 @@ static void osinfo_loader_deployment(OsinfoLoader *loader,
                                      xmlNodePtr root,
                                      GError **err)
 {
+    OsinfoOs *os;
+    OsinfoPlatform *platform;
+    OsinfoDeployment *deployment;
+    gchar *platformid;
+    gchar *osid;
     gchar *id = (gchar *)xmlGetProp(root, BAD_CAST "id");
     if (!id) {
         OSINFO_LOADER_SET_ERROR(err, _("Missing deployment id property"));
@@ -808,26 +833,26 @@ static void osinfo_loader_deployment(OsinfoLoader *loader,
         return;
     }
 
-    gchar *osid = osinfo_loader_string("string(./os/@id)", loader, ctxt, err);
+    osid = osinfo_loader_string("string(./os/@id)", loader, ctxt, err);
     if (!osid && 0) {
         OSINFO_LOADER_SET_ERROR(err, _("Missing deployment os id property"));
         xmlFree(id);
         return;
     }
-    OsinfoOs *os = osinfo_loader_get_os(loader, osid);
+    os = osinfo_loader_get_os(loader, osid);
     g_free(osid);
 
-    gchar *platformid = osinfo_loader_string("string(./platform/@id)", loader,
+    platformid = osinfo_loader_string("string(./platform/@id)", loader,
                                              ctxt, err);
     if (!platformid) {
         OSINFO_LOADER_SET_ERROR(err, _("Missing deployment platform id property"));
         xmlFree(id);
         return;
     }
-    OsinfoPlatform *platform = osinfo_loader_get_platform(loader, platformid);
+    platform = osinfo_loader_get_platform(loader, platformid);
     g_free(platformid);
 
-    OsinfoDeployment *deployment = osinfo_deployment_new(id, os, platform);
+    deployment = osinfo_deployment_new(id, os, platform);
     xmlFree(id);
 
     osinfo_loader_entity(loader, OSINFO_ENTITY(deployment), NULL, ctxt, root, err);
@@ -855,7 +880,7 @@ static void osinfo_loader_datamap(OsinfoLoader *loader,
     xmlNodePtr *nodes = NULL;
     guint i;
     int nnodes;
-
+    OsinfoDatamap *map;
     gchar *id = (gchar *)xmlGetProp(root, BAD_CAST "id");
 
     if (!id) {
@@ -867,7 +892,7 @@ static void osinfo_loader_datamap(OsinfoLoader *loader,
         return;
     }
 
-    OsinfoDatamap *map = osinfo_loader_get_datamap(loader, id);
+    map = osinfo_loader_get_datamap(loader, id);
     g_hash_table_remove(loader->priv->entity_refs, id);
 
     nnodes = osinfo_loader_nodeset("./entry", loader, ctxt, &nodes, err);
@@ -981,6 +1006,7 @@ static void osinfo_loader_install_script(OsinfoLoader *loader,
     int i, nnodes;
     unsigned int injection_methods = 0;
     GFlagsClass *flags_class;
+    OsinfoInstallScript *installScript;
 
     if (!id) {
         OSINFO_LOADER_SET_ERROR(err, _("Missing install script id property"));
@@ -991,8 +1017,7 @@ static void osinfo_loader_install_script(OsinfoLoader *loader,
         xmlFree(id);
         return;
     }
-    OsinfoInstallScript *installScript = osinfo_loader_get_install_script(loader,
-                                                                          id);
+    installScript = osinfo_loader_get_install_script(loader, id);
     g_hash_table_remove(loader->priv->entity_refs, id);
     xmlFree(id);
 
@@ -1080,6 +1105,7 @@ static OsinfoMedia *osinfo_loader_media(OsinfoLoader *loader,
                                          GError **err)
 {
     xmlNodePtr *nodes = NULL;
+    gint nnodes;
     guint i;
 
     gchar *arch = (gchar *)xmlGetProp(root, BAD_CAST "arch");
@@ -1137,7 +1163,7 @@ static OsinfoMedia *osinfo_loader_media(OsinfoLoader *loader,
         xmlFree(installer_script);
     }
 
-    gint nnodes = osinfo_loader_nodeset("./variant", loader, ctxt, &nodes, err);
+    nnodes = osinfo_loader_nodeset("./variant", loader, ctxt, &nodes, err);
     if (error_is_set(err)) {
         g_object_unref(media);
         return NULL;
@@ -1240,6 +1266,7 @@ static OsinfoTree *osinfo_loader_tree(OsinfoLoader *loader,
                                          GError **err)
 {
     xmlNodePtr *nodes = NULL;
+    gint nnodes;
     guint i;
 
     gchar *arch = (gchar *)xmlGetProp(root, BAD_CAST "arch");
@@ -1254,7 +1281,7 @@ static OsinfoTree *osinfo_loader_tree(OsinfoLoader *loader,
     OsinfoTree *tree = osinfo_tree_new(id, arch);
     xmlFree(arch);
 
-    gint nnodes = osinfo_loader_nodeset("./variant", loader, ctxt, &nodes, err);
+    nnodes = osinfo_loader_nodeset("./variant", loader, ctxt, &nodes, err);
     if (error_is_set(err)) {
         g_object_unref(tree);
         return NULL;
@@ -1508,6 +1535,7 @@ static OsinfoDeviceDriver *osinfo_loader_driver(OsinfoLoader *loader,
                                                 GError **err)
 {
     xmlNodePtr *nodes = NULL;
+    gint nnodes;
     guint i;
 
     xmlChar *arch = xmlGetProp(root, BAD_CAST OSINFO_DEVICE_DRIVER_PROP_ARCHITECTURE);
@@ -1553,7 +1581,7 @@ static OsinfoDeviceDriver *osinfo_loader_driver(OsinfoLoader *loader,
         xmlFree(priority);
     }
 
-    gint nnodes = osinfo_loader_nodeset("./*", loader, ctxt, &nodes, err);
+    nnodes = osinfo_loader_nodeset("./*", loader, ctxt, &nodes, err);
     if (error_is_set(err)) {
         g_object_unref(G_OBJECT(driver));
         return NULL;
@@ -1600,8 +1628,10 @@ static void osinfo_loader_os(OsinfoLoader *loader,
         { OSINFO_OS_PROP_DISTRO, G_TYPE_STRING },
         { OSINFO_OS_PROP_RELEASE_STATUS, G_TYPE_STRING },
         { OSINFO_OS_PROP_KERNEL_URL_ARGUMENT, G_TYPE_STRING },
+        { OSINFO_OS_PROP_CLOUD_IMAGE_USERNAME, G_TYPE_STRING },
         { NULL, G_TYPE_INVALID }
     };
+    OsinfoOs *os;
 
     if (!id) {
         OSINFO_LOADER_SET_ERROR(err, _("Missing os id property"));
@@ -1612,7 +1642,7 @@ static void osinfo_loader_os(OsinfoLoader *loader,
         return;
     }
 
-    OsinfoOs *os = osinfo_loader_get_os(loader, id);
+    os = osinfo_loader_get_os(loader, id);
     g_hash_table_remove(loader->priv->entity_refs, id);
 
     osinfo_loader_entity(loader, OSINFO_ENTITY(os), keys, ctxt, root, err);
@@ -1633,10 +1663,13 @@ static void osinfo_loader_os(OsinfoLoader *loader,
         goto cleanup;
 
     for (i = 0; i < nnodes; i++) {
+        gchar *firmware_id;
+        OsinfoFirmware *firmware;
         xmlNodePtr saved = ctxt->node;
+
         ctxt->node = nodes[i];
-        gchar *firmware_id = g_strdup_printf("%s:%u", id, i);
-        OsinfoFirmware *firmware = osinfo_loader_firmware(loader, ctxt, nodes[i], firmware_id, err);
+        firmware_id = osinfo_build_internal_id(relpath, id, i);
+        firmware = osinfo_loader_firmware(loader, ctxt, nodes[i], firmware_id, err);
         g_free(firmware_id);
         ctxt->node = saved;
         if (error_is_set(err))
@@ -1651,10 +1684,13 @@ static void osinfo_loader_os(OsinfoLoader *loader,
         goto cleanup;
 
     for (i = 0; i < nnodes; i++) {
+        gchar *media_id;
+        OsinfoMedia *media;
         xmlNodePtr saved = ctxt->node;
+
         ctxt->node = nodes[i];
-        gchar *media_id = g_strdup_printf("%s:%u", id, i);
-        OsinfoMedia *media = osinfo_loader_media(loader, ctxt, nodes[i], media_id, err);
+        media_id = osinfo_build_internal_id(relpath, id, i);
+        media = osinfo_loader_media(loader, ctxt, nodes[i], media_id, err);
         g_free(media_id);
         ctxt->node = saved;
         if (error_is_set(err))
@@ -1671,10 +1707,13 @@ static void osinfo_loader_os(OsinfoLoader *loader,
         goto cleanup;
 
     for (i = 0; i < nnodes; i++) {
+        gchar *tree_id;
+        OsinfoTree *tree;
         xmlNodePtr saved = ctxt->node;
+
         ctxt->node = nodes[i];
-        gchar *tree_id = g_strdup_printf("%s:%u", id, i);
-        OsinfoTree *tree = osinfo_loader_tree(loader, ctxt, nodes[i], tree_id, err);
+        tree_id = osinfo_build_internal_id(relpath, id, i);
+        tree = osinfo_loader_tree(loader, ctxt, nodes[i], tree_id, err);
         g_free(tree_id);
         ctxt->node = saved;
         if (error_is_set(err))
@@ -1691,10 +1730,13 @@ static void osinfo_loader_os(OsinfoLoader *loader,
         goto cleanup;
 
     for (i = 0; i < nnodes; i++) {
+        gchar *image_id;
+        OsinfoImage *image;
         xmlNodePtr saved = ctxt->node;
+
         ctxt->node = nodes[i];
-        gchar *image_id = g_strdup_printf("%s:%u", id, i);
-        OsinfoImage *image = osinfo_loader_image(loader, ctxt, nodes[i], image_id, err);
+        image_id = osinfo_build_internal_id(relpath, id, i);
+        image = osinfo_loader_image(loader, ctxt, nodes[i], image_id, err);
         g_free(image_id);
         ctxt->node = saved;
         if (error_is_set(err))
@@ -1711,12 +1753,13 @@ static void osinfo_loader_os(OsinfoLoader *loader,
         goto cleanup;
 
     for (i = 0; i < nnodes; i++) {
+        OsinfoOsVariant *variant;
         xmlNodePtr saved = ctxt->node;
         ctxt->node = nodes[i];
-        OsinfoOsVariant *variant = osinfo_loader_os_variant(loader,
-                                                            ctxt,
-                                                            nodes[i],
-                                                            err);
+        variant = osinfo_loader_os_variant(loader,
+                                           ctxt,
+                                           nodes[i],
+                                           err);
         ctxt->node = saved;
         if (error_is_set(err))
             goto cleanup;
@@ -1732,9 +1775,10 @@ static void osinfo_loader_os(OsinfoLoader *loader,
         goto cleanup;
 
     for (i = 0; i < nnodes; i++) {
+        gchar *resources_id;
         xmlNodePtr saved = ctxt->node;
         ctxt->node = nodes[i];
-        gchar *resources_id = g_strdup_printf("%s:%u", id, i);
+        resources_id = osinfo_build_internal_id(relpath, id, i);
 
         osinfo_loader_resources_list(loader,
                                      ctxt,
@@ -1755,12 +1799,12 @@ static void osinfo_loader_os(OsinfoLoader *loader,
         goto cleanup;
 
     for (i = 0; i < nnodes; i++) {
+        OsinfoInstallScript *script;
         gchar *scriptid = (gchar *)xmlGetProp(nodes[i], BAD_CAST "id");
         if (!scriptid) {
             OSINFO_LOADER_SET_ERROR(err, _("Missing OS install script property"));
             goto cleanup;
         }
-        OsinfoInstallScript *script;
         script = osinfo_loader_get_install_script(loader, scriptid);
         xmlFree(scriptid);
 
@@ -1774,14 +1818,17 @@ static void osinfo_loader_os(OsinfoLoader *loader,
         goto cleanup;
 
     for (i = 0; i < nnodes; i++) {
+        gchar *driver_id;
+        OsinfoDeviceDriver *driver;
         xmlNodePtr saved = ctxt->node;
+
         ctxt->node = nodes[i];
-        gchar *driver_id = g_strdup_printf("%s:%u", id, i);
-        OsinfoDeviceDriver *driver= osinfo_loader_driver(loader,
-                                                         ctxt,
-                                                         nodes[i],
-                                                         driver_id,
-                                                         err);
+        driver_id = osinfo_build_internal_id(relpath, id, i);
+        driver= osinfo_loader_driver(loader,
+                                     ctxt,
+                                     nodes[i],
+                                     driver_id,
+                                     err);
         g_free(driver_id);
         ctxt->node = saved;
         if (error_is_set(err))
@@ -1826,10 +1873,12 @@ static void osinfo_loader_root(OsinfoLoader *loader,
     }
 
     for (it = root->children; it; it = it->next) {
+        xmlNodePtr saved;
+
         if (it->type != XML_ELEMENT_NODE)
             continue;
 
-        xmlNodePtr saved = ctxt->node;
+        saved = ctxt->node;
         ctxt->node = it;
 
         if (xmlStrEqual(it->name, BAD_CAST "device"))
@@ -1937,11 +1986,8 @@ osinfo_loader_process_file_reg_ids(OsinfoLoader *loader,
                                    const char *busType,
                                    GError **err)
 {
-    GFileInputStream *is = g_file_read(file, NULL, err);
-    if (error_is_set(err))
-        return;
-
-    GDataInputStream *dis = g_data_input_stream_new(G_INPUT_STREAM(is));
+    GFileInputStream *is;
+    GDataInputStream *dis;
 
     gchar *data;
     gsize datalen;
@@ -1956,6 +2002,12 @@ osinfo_loader_process_file_reg_ids(OsinfoLoader *loader,
     gchar *subvendor_id = NULL;
     gchar *subdevice_id = NULL;
 
+    is = g_file_read(file, NULL, err);
+    if (error_is_set(err))
+        return;
+
+    dis = g_data_input_stream_new(G_INPUT_STREAM(is));
+
     while ((data = g_data_input_stream_read_line(dis, &datalen, NULL, err)) != NULL) {
         char *tmp = data;
         gsize offset = 0;
@@ -2009,16 +2061,22 @@ osinfo_loader_process_file_reg_ids(OsinfoLoader *loader,
                 ignore_value(subdevice_id);
                 ignore_value(subsystem);
             } else {
+                gchar *id;
+                gchar *key;
+                OsinfoLoaderEntityFiles *files;
+                OsinfoDevice *dev;
+                OsinfoEntity *entity;
+
                 FREE_BUF(device_buf);
                 WANT_ID(device_id);
                 WANT_REST(device);
                 SAVE_BUF(device_buf);
 
-                gchar *id = g_strdup_printf("%s/%s/%s/%s",
+                id = g_strdup_printf("%s/%s/%s/%s",
                                             baseURI, busType, vendor_id, device_id);
-                gchar *key = g_strdup_printf("/device/%s/%s-%s-%s",
+                key = g_strdup_printf("/device/%s/%s-%s-%s",
                                               baseURI + 7, busType, vendor_id, device_id);
-                OsinfoLoaderEntityFiles *files = g_hash_table_lookup(allentries, key);
+                files = g_hash_table_lookup(allentries, key);
                 g_free(key);
                 if (files && files->master) {
                     /* Native database has a matching entry that completely
@@ -2026,9 +2084,9 @@ osinfo_loader_process_file_reg_ids(OsinfoLoader *loader,
                     continue;
                 }
 
-                OsinfoDevice *dev = osinfo_loader_get_device(loader, id);
+                dev = osinfo_loader_get_device(loader, id);
                 g_hash_table_remove(loader->priv->entity_refs, id);
-                OsinfoEntity *entity = OSINFO_ENTITY(dev);
+                entity = OSINFO_ENTITY(dev);
                 osinfo_entity_set_param(entity,
                                         OSINFO_DEVICE_PROP_VENDOR_ID,
                                         vendor_id);
@@ -2104,6 +2162,7 @@ osinfo_loader_process_file_reg_xml(OsinfoLoader *loader,
     gchar *xml = NULL;
     gsize xmlLen;
     gchar *relpath = NULL;
+    gchar *uri = NULL;
 
     g_file_load_contents(file, NULL, &xml, &xmlLen, NULL, err);
     if (error_is_set(err))
@@ -2116,7 +2175,7 @@ osinfo_loader_process_file_reg_xml(OsinfoLoader *loader,
             g_warning("File %s does not have expected prefix", relpath);
         }
     }
-    gchar *uri = g_file_get_uri(file);
+    uri = g_file_get_uri(file);
     osinfo_loader_process_xml(loader,
                               relpath,
                               xml,
@@ -2271,9 +2330,12 @@ static void osinfo_loader_find_files(OsinfoLoader *loader,
         children = g_list_sort(children, osinfo_sort_files);
         tmp = children;
         while (tmp) {
+            const gchar *name;
+            GFile *ent;
+
             info = tmp->data;
-            const gchar *name = g_file_info_get_name(info);
-            GFile *ent = g_file_get_child(file, name);
+            name = g_file_info_get_name(info);
+            ent = g_file_get_child(file, name);
             type = g_file_info_get_attribute_uint32(info,
                                                     G_FILE_ATTRIBUTE_STANDARD_TYPE);
             if (type == G_FILE_TYPE_REGULAR) {
@@ -2325,16 +2387,17 @@ static void osinfo_loader_process_list(OsinfoLoader *loader,
     tmp = dirs;
     while (tmp && *tmp) {
         OsinfoLoaderDataFormat fmt = GPOINTER_TO_INT(g_object_get_data(G_OBJECT(*tmp), "data-format"));
+        GHashTable *entries;
 
         if (fmt != OSINFO_DATA_FORMAT_NATIVE) {
             tmp++;
             continue;
         }
 
-        GHashTable *entries = g_hash_table_new_full(g_str_hash,
-                                                    g_str_equal,
-                                                    g_free,
-                                                    (GDestroyNotify)osinfo_loader_entity_files_free);
+        entries = g_hash_table_new_full(g_str_hash,
+                                        g_str_equal,
+                                        g_free,
+                                        (GDestroyNotify)osinfo_loader_entity_files_free);
 
         osinfo_loader_find_files(loader, *tmp, *tmp, entries, skipMissing, &lerr);
         if (lerr) {
