@@ -1,7 +1,7 @@
 /*
  * libosinfo: An installation media for a (guest) OS
  *
- * Copyright (C) 2009-2012, 2014 Red Hat, Inc.
+ * Copyright (C) 2009-2020 Red Hat, Inc.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -16,11 +16,6 @@
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library. If not, see
  * <http://www.gnu.org/licenses/>.
- *
- * Authors:
- *   Zeeshan Ali <zeenix@redhat.com>
- *   Arjun Roy <arroy@redhat.com>
- *   Daniel P. Berrange <berrange@redhat.com>
  */
 
 #include <osinfo/osinfo.h>
@@ -194,13 +189,6 @@ osinfo_media_error_quark(void)
     return quark;
 }
 
-G_DEFINE_TYPE(OsinfoMedia, osinfo_media, OSINFO_TYPE_ENTITY);
-
-#define OSINFO_MEDIA_GET_PRIVATE(obj) \
-        (G_TYPE_INSTANCE_GET_PRIVATE((obj), \
-                                     OSINFO_TYPE_MEDIA,         \
-                                     OsinfoMediaPrivate))
-
 /**
  * SECTION:osinfo_media
  * @short_description: An installation media for a (guest) OS
@@ -216,6 +204,8 @@ struct _OsinfoMediaPrivate
     OsinfoInstallScriptList *scripts;
 };
 
+G_DEFINE_TYPE_WITH_PRIVATE(OsinfoMedia, osinfo_media, OSINFO_TYPE_ENTITY);
+
 enum {
     PROP_0,
 
@@ -234,8 +224,11 @@ enum {
     PROP_LANGUAGES,
     PROP_VOLUME_SIZE,
     PROP_EJECT_AFTER_INSTALL,
-    PROP_INSTALLER_SCRIPT
+    PROP_INSTALLER_SCRIPT,
+
+    LAST_PROP
 };
+static GParamSpec *properties[LAST_PROP];
 
 static void
 osinfo_media_get_property(GObject    *object,
@@ -465,143 +458,131 @@ static void
 osinfo_media_class_init(OsinfoMediaClass *klass)
 {
     GObjectClass *g_klass = G_OBJECT_CLASS(klass);
-    GParamSpec *pspec;
 
     g_klass->dispose = osinfo_media_dispose;
     g_klass->finalize = osinfo_media_finalize;
     g_klass->get_property = osinfo_media_get_property;
     g_klass->set_property = osinfo_media_set_property;
-    g_type_class_add_private(klass, sizeof(OsinfoMediaPrivate));
 
     /**
      * OsinfoMedia:architecture:
      *
      * The target hardware architecture of this media.
      */
-    pspec = g_param_spec_string("architecture",
-                                "ARCHITECTURE",
-                                _("CPU Architecture"),
-                                NULL /* default value */,
-                                G_PARAM_READWRITE |
-                                G_PARAM_STATIC_STRINGS);
-    g_object_class_install_property(g_klass, PROP_ARCHITECTURE, pspec);
+    properties[PROP_ARCHITECTURE] = g_param_spec_string("architecture",
+                                                        "ARCHITECTURE",
+                                                        _("CPU Architecture"),
+                                                        NULL /* default value */,
+                                                        G_PARAM_READWRITE |
+                                                        G_PARAM_STATIC_STRINGS);
 
     /**
      * OsinfoMedia:url:
      *
      * The URL to this media.
      */
-    pspec = g_param_spec_string("url",
-                                "URL",
-                                _("The URL to this media"),
-                                NULL /* default value */,
-                                G_PARAM_READWRITE |
-                                G_PARAM_STATIC_STRINGS);
-    g_object_class_install_property(g_klass, PROP_URL, pspec);
+    properties[PROP_URL] = g_param_spec_string("url",
+                                               "URL",
+                                               _("The URL to this media"),
+                                               NULL /* default value */,
+                                               G_PARAM_READWRITE |
+                                               G_PARAM_STATIC_STRINGS);
 
     /**
      * OsinfoMedia:volume-id:
      *
      * Expected volume ID (regular expression) for ISO9660 image/device.
      */
-    pspec = g_param_spec_string("volume-id",
-                                "VolumeID",
-                                _("The expected ISO9660 volume ID"),
-                                NULL /* default value */,
-                                G_PARAM_READWRITE |
-                                G_PARAM_STATIC_STRINGS);
-    g_object_class_install_property(g_klass, PROP_VOLUME_ID, pspec);
+    properties[PROP_VOLUME_ID] = g_param_spec_string("volume-id",
+                                                     "VolumeID",
+                                                     _("The expected ISO9660 volume ID"),
+                                                     NULL /* default value */,
+                                                     G_PARAM_READWRITE |
+                                                     G_PARAM_STATIC_STRINGS);
 
     /**
      * OsinfoMedia:publisher-id:
      *
      * Expected publisher ID (regular expression) for ISO9660 image/device.
      */
-    pspec = g_param_spec_string("publisher-id",
-                                "PublisherID",
-                                _("The expected ISO9660 publisher ID"),
-                                NULL /* default value */,
-                                G_PARAM_READWRITE |
-                                G_PARAM_STATIC_STRINGS);
-    g_object_class_install_property(g_klass, PROP_PUBLISHER_ID, pspec);
+    properties[PROP_PUBLISHER_ID] = g_param_spec_string("publisher-id",
+                                                        "PublisherID",
+                                                        _("The expected ISO9660 publisher ID"),
+                                                        NULL /* default value */,
+                                                        G_PARAM_READWRITE |
+                                                        G_PARAM_STATIC_STRINGS);
 
     /**
      * OsinfoMedia:application-id:
      *
      * Expected application ID (regular expression) for ISO9660 image/device.
      */
-    pspec = g_param_spec_string("application-id",
-                                "ApplicationID",
-                                _("The expected ISO9660 application ID"),
-                                NULL /* default value */,
-                                G_PARAM_READWRITE |
-                                G_PARAM_STATIC_STRINGS);
-    g_object_class_install_property(g_klass, PROP_APPLICATION_ID, pspec);
+    properties[PROP_APPLICATION_ID] = g_param_spec_string("application-id",
+                                                          "ApplicationID",
+                                                          _("The expected ISO9660 application ID"),
+                                                          NULL /* default value */,
+                                                          G_PARAM_READWRITE |
+                                                          G_PARAM_STATIC_STRINGS);
 
     /**
      * OsinfoMedia:system-id:
      *
      * Expected system ID (regular expression) for ISO9660 image/device.
      */
-    pspec = g_param_spec_string("system-id",
-                                "SystemID",
-                                _("The expected ISO9660 system ID"),
-                                NULL /* default value */,
-                                G_PARAM_READWRITE |
-                                G_PARAM_STATIC_STRINGS);
-    g_object_class_install_property(g_klass, PROP_SYSTEM_ID, pspec);
+    properties[PROP_SYSTEM_ID] = g_param_spec_string("system-id",
+                                                     "SystemID",
+                                                     _("The expected ISO9660 system ID"),
+                                                     NULL /* default value */,
+                                                     G_PARAM_READWRITE |
+                                                     G_PARAM_STATIC_STRINGS);
 
     /**
      * OsinfoMedia:kernel-path:
      *
      * The path to the kernel image in the install tree.
      */
-    pspec = g_param_spec_string("kernel-path",
-                                "KernelPath",
-                                _("The path to the kernel image"),
-                                NULL /* default value */,
-                                G_PARAM_READWRITE |
-                                G_PARAM_STATIC_STRINGS);
-    g_object_class_install_property(g_klass, PROP_KERNEL_PATH, pspec);
+    properties[PROP_KERNEL_PATH] = g_param_spec_string("kernel-path",
+                                                       "KernelPath",
+                                                       _("The path to the kernel image"),
+                                                       NULL /* default value */,
+                                                       G_PARAM_READWRITE |
+                                                       G_PARAM_STATIC_STRINGS);
 
     /**
      * OsinfoMedia:initrd-path:
      *
      * The path to the initrd image in the install tree.
      */
-    pspec = g_param_spec_string("initrd-path",
-                                "InitrdPath",
-                                _("The path to the initrd image"),
-                                NULL /* default value */,
-                                G_PARAM_READWRITE |
-                                G_PARAM_STATIC_STRINGS);
-    g_object_class_install_property(g_klass, PROP_INITRD_PATH, pspec);
+    properties[PROP_INITRD_PATH] = g_param_spec_string("initrd-path",
+                                                       "InitrdPath",
+                                                       _("The path to the initrd image"),
+                                                       NULL /* default value */,
+                                                       G_PARAM_READWRITE |
+                                                       G_PARAM_STATIC_STRINGS);
 
     /**
      * OsinfoMedia:installer:
      *
      * Whether media provides an installer for an OS.
      */
-    pspec = g_param_spec_boolean("installer",
-                                 "Installer",
-                                 _("Media provides an installer"),
-                                 TRUE /* default value */,
-                                 G_PARAM_READWRITE |
-                                 G_PARAM_STATIC_STRINGS);
-    g_object_class_install_property(g_klass, PROP_INSTALLER, pspec);
+    properties[PROP_INSTALLER] = g_param_spec_boolean("installer",
+                                                      "Installer",
+                                                      _("Media provides an installer"),
+                                                      TRUE /* default value */,
+                                                      G_PARAM_READWRITE |
+                                                      G_PARAM_STATIC_STRINGS);
 
     /**
      * OsinfoMedia:live:
      *
      * Whether media can boot directly an OS without any installations.
      */
-    pspec = g_param_spec_boolean("live",
-                                 "Live",
-                                 _("Media can boot directly w/o installation"),
-                                 FALSE /* default value */,
-                                 G_PARAM_READWRITE |
-                                 G_PARAM_STATIC_STRINGS);
-    g_object_class_install_property(g_klass, PROP_LIVE, pspec);
+    properties[PROP_LIVE] = g_param_spec_boolean("live",
+                                                 "Live",
+                                                 _("Media can boot directly w/o installation"),
+                                                 FALSE /* default value */,
+                                                 G_PARAM_READWRITE |
+                                                 G_PARAM_STATIC_STRINGS);
 
     /**
      * OsinfoMedia:installer-reboots:
@@ -617,34 +598,32 @@ osinfo_media_class_init(OsinfoMediaClass *klass)
      * case number of reboots *alone* is not a reliable method for tracking
      * installation.
      */
-    pspec = g_param_spec_int("installer-reboots",
-                             "InstallerReboots",
-                             _("Number of installer reboots"),
-                             G_MININT,
-                             G_MAXINT,
-                             1 /* default value */,
-                             G_PARAM_READWRITE |
-                             G_PARAM_STATIC_STRINGS);
-    g_object_class_install_property(g_klass, PROP_INSTALLER_REBOOTS, pspec);
+    properties[PROP_INSTALLER_REBOOTS] = g_param_spec_int("installer-reboots",
+                                                          "InstallerReboots",
+                                                          _("Number of installer reboots"),
+                                                          G_MININT,
+                                                          G_MAXINT,
+                                                          1 /* default value */,
+                                                          G_PARAM_READWRITE |
+                                                          G_PARAM_STATIC_STRINGS);
 
     /**
      * OsinfoMedia:os:
      *
      * Os information for the current media. For media stored in an
-     * #OsinfoDB, it will be filled when the database is loaded, otherwise
+     * #OsinfoDb, it will be filled when the database is loaded, otherwise
      * the property will be filled after a successful call to
      * osinfo_db_identify_media().
      */
-    pspec = g_param_spec_object("os",
-                                "Os",
-                                _("Information about the operating system on this media"),
-                                OSINFO_TYPE_OS,
-                                G_PARAM_READWRITE |
-                                G_PARAM_STATIC_STRINGS);
-    g_object_class_install_property(g_klass, PROP_OS, pspec);
+    properties[PROP_OS] = g_param_spec_object("os",
+                                              "Os",
+                                              _("Information about the operating system on this media"),
+                                              OSINFO_TYPE_OS,
+                                              G_PARAM_READWRITE |
+                                              G_PARAM_STATIC_STRINGS);
 
     /**
-     * OsinfoMedia:languages:
+     * OsinfoMedia:languages: (type GLib.List(utf8)) (transfer container):
      *
      * If media is an installer, this property indicates the languages that
      * can be used during automatic installations.
@@ -653,31 +632,26 @@ osinfo_media_class_init(OsinfoMediaClass *klass)
      * languages that the user interface can be displayed in.
      * Use #osinfo_media_get_installer(or OsinfoMedia::installer) to know
      * if the media is an installer or not.
-     *
-     * Type: GLib.List(utf8)
-     * Transfer: container
      */
-    pspec = g_param_spec_pointer("languages",
-                                 "Languages",
-                                 _("Supported languages"),
-                                 G_PARAM_READABLE |
-                                 G_PARAM_STATIC_STRINGS);
-    g_object_class_install_property(g_klass, PROP_LANGUAGES, pspec);
+    properties[PROP_LANGUAGES] = g_param_spec_pointer("languages",
+                                                      "Languages",
+                                                      _("Supported languages"),
+                                                      G_PARAM_READABLE |
+                                                      G_PARAM_STATIC_STRINGS);
 
     /**
      * OsinfoMedia:volume-size:
      *
      * Expected volume size, in bytes for ISO9660 image/device.
      */
-    pspec = g_param_spec_int64("volume-size",
-                               "VolumeSize",
-                               _("Expected ISO9660 volume size, in bytes"),
-                               G_MININT,
-                               G_MAXINT64,
-                               -1 /* default value */,
-                               G_PARAM_READWRITE |
-                               G_PARAM_STATIC_STRINGS);
-    g_object_class_install_property(g_klass, PROP_VOLUME_SIZE, pspec);
+    properties[PROP_VOLUME_SIZE] = g_param_spec_int64("volume-size",
+                                                      "VolumeSize",
+                                                      _("Expected ISO9660 volume size, in bytes"),
+                                                      G_MININT,
+                                                      G_MAXINT64,
+                                                      -1 /* default value */,
+                                                      G_PARAM_READWRITE |
+                                                      G_PARAM_STATIC_STRINGS);
 
     /**
      * OsinfoMedia:eject-after-install:
@@ -689,13 +663,12 @@ osinfo_media_class_init(OsinfoMediaClass *klass)
      * reboot (which may cause the media to be ejected, depending on the
      * application).
      */
-    pspec = g_param_spec_boolean("eject-after-install",
-                                 "EjectAfterInstall",
-                                 _("Whether the media should be ejected after the installtion process"),
-                                 TRUE /* default value */,
-                                 G_PARAM_READWRITE |
-                                 G_PARAM_STATIC_STRINGS);
-    g_object_class_install_property(g_klass, PROP_EJECT_AFTER_INSTALL, pspec);
+    properties[PROP_EJECT_AFTER_INSTALL] = g_param_spec_boolean("eject-after-install",
+                                                                "EjectAfterInstall",
+                                                                _("Whether the media should be ejected after the installation process"),
+                                                                TRUE /* default value */,
+                                                                G_PARAM_READWRITE |
+                                                                G_PARAM_STATIC_STRINGS);
 
     /**
      * OsinfoMedia:installer-script:
@@ -705,19 +678,20 @@ osinfo_media_class_init(OsinfoMediaClass *klass)
      * Some distros provide a few different medias and not all the medias support
      * installation via an install script.
      */
-    pspec = g_param_spec_boolean("installer-script",
-                                 "InstallerScript",
-                                 _("Whether the media should be used for an installation using install scripts"),
-                                 TRUE /* default value */,
-                                 G_PARAM_READWRITE |
-                                 G_PARAM_STATIC_STRINGS);
-    g_object_class_install_property(g_klass, PROP_INSTALLER_SCRIPT, pspec);
+    properties[PROP_INSTALLER_SCRIPT] = g_param_spec_boolean("installer-script",
+                                                             "InstallerScript",
+                                                             _("Whether the media should be used for an installation using install scripts"),
+                                                             TRUE /* default value */,
+                                                             G_PARAM_READWRITE |
+                                                             G_PARAM_STATIC_STRINGS);
+
+    g_object_class_install_properties(g_klass, LAST_PROP, properties);
 }
 
 static void
 osinfo_media_init(OsinfoMedia *media)
 {
-    media->priv = OSINFO_MEDIA_GET_PRIVATE(media);
+    media->priv = osinfo_media_get_instance_private(media);
     g_weak_ref_init(&media->priv->os, NULL);
     media->priv->scripts = osinfo_install_scriptlist_new();
 }
@@ -1412,7 +1386,9 @@ void osinfo_media_create_from_location_with_flags_async(const gchar *location,
     data->uri = g_strdup(location);
 
     if (osinfo_util_requires_soup(location)) {
-        data->session = soup_session_new();
+        data->session = soup_session_new_with_options(
+                SOUP_SESSION_USER_AGENT, "Wget/1.0",
+                NULL);
         data->message = soup_message_new("GET", location);
 
         soup_session_send_async(data->session,
@@ -1632,8 +1608,7 @@ gboolean osinfo_media_get_live(OsinfoMedia *media)
  * Warning: Some media allow you to install from live sessions, in which case
  * number of reboots *alone* is not a reliable method for tracking installation.
  *
- * Returns: (transfer none): the number of installer reboots or -1 if media is
- * not an installer
+ * Returns: the number of installer reboots or -1 if media is not an installer
  *
  * Since: 0.2.1
  */
@@ -1765,7 +1740,7 @@ void osinfo_media_set_languages(OsinfoMedia *media, GList *languages)
  * osinfo_media_get_volume_size:
  * @media: an #OsinfoMedia instance
  *
- * Returns: (transfer none): the ISO9660 volume size, in bytes or -1 if size is
+ * Returns: the ISO9660 volume size, in bytes or -1 if size is
  * unknown or media is not an ISO9660 device/image.
  */
 gint64 osinfo_media_get_volume_size(OsinfoMedia *media)
