@@ -1,7 +1,7 @@
 /*
  * libosinfo:
  *
- * Copyright (C) 2009-2012, 2014 Red Hat, Inc.
+ * Copyright (C) 2009-2020 Red Hat, Inc.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -16,10 +16,6 @@
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library. If not, see
  * <http://www.gnu.org/licenses/>.
- *
- * Authors:
- *   Arjun Roy <arroy@redhat.com>
- *   Daniel P. Berrange <berrange@redhat.com>
  */
 
 #include <osinfo/osinfo.h>
@@ -28,10 +24,6 @@
 #include "osinfo/osinfo_resources_private.h"
 #include <glib/gi18n-lib.h>
 
-G_DEFINE_TYPE(OsinfoOs, osinfo_os, OSINFO_TYPE_PRODUCT);
-
-#define OSINFO_OS_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE((obj), OSINFO_TYPE_OS, OsinfoOsPrivate))
-
 /**
  * SECTION:osinfo_os
  * @short_description: An operating system
@@ -64,6 +56,8 @@ struct _OsinfoOsPrivate
     OsinfoDeviceDriverList *device_drivers;
 };
 
+G_DEFINE_TYPE_WITH_PRIVATE(OsinfoOs, osinfo_os, OSINFO_TYPE_PRODUCT);
+
 struct _OsinfoOsDeviceLink {
     OsinfoDevice *dev;
     gchar *driver;
@@ -75,7 +69,10 @@ enum {
     PROP_FAMILY,
     PROP_DISTRO,
     PROP_KERNEL_URL_ARGUMENT,
+    PROP_CLOUD_IMAGE_USERNAME,
+    LAST_PROP
 };
+static GParamSpec *properties[LAST_PROP];
 
 static void osinfo_os_finalize(GObject *object);
 
@@ -104,6 +101,11 @@ osinfo_os_get_property(GObject    *object,
                                osinfo_entity_get_param_value(entity,
                                                              OSINFO_OS_PROP_KERNEL_URL_ARGUMENT));
             break;
+        case PROP_CLOUD_IMAGE_USERNAME:
+            g_value_set_string(value,
+                               osinfo_entity_get_param_value(entity,
+                                                             OSINFO_OS_PROP_CLOUD_IMAGE_USERNAME));
+            break;
         default:
             /* We don't have any other property... */
             G_OBJECT_WARN_INVALID_PROPERTY_ID(object, property_id, pspec);
@@ -140,28 +142,22 @@ static void
 osinfo_os_class_init(OsinfoOsClass *klass)
 {
     GObjectClass *g_klass = G_OBJECT_CLASS(klass);
-    GParamSpec *pspec;
 
     g_klass->get_property = osinfo_os_get_property;
     g_klass->finalize = osinfo_os_finalize;
 
-    g_type_class_add_private(klass, sizeof(OsinfoOsPrivate));
-
     /**
      * OsinfoOs:family:
      *
      * The generic family this OS belongs to, based upon its kernel,
      * for example linux, winnt, solaris, freebsd etc.
      */
-    pspec = g_param_spec_string("family",
-                                "Family",
-                                _("Generic Family"),
-                                NULL /* default value */,
-                                G_PARAM_READABLE |
-                                G_PARAM_STATIC_STRINGS);
-    g_object_class_install_property(g_klass,
-                                     PROP_FAMILY,
-                                     pspec);
+    properties[PROP_FAMILY] = g_param_spec_string("family",
+                                                  "Family",
+                                                  _("Generic Family"),
+                                                  NULL /* default value */,
+                                                  G_PARAM_READABLE |
+                                                  G_PARAM_STATIC_STRINGS);
 
     /**
      * OsinfoOs:distro:
@@ -169,15 +165,12 @@ osinfo_os_class_init(OsinfoOsClass *klass)
      * The generic distro this OS belongs to, for example fedora, windows,
      * solaris, freebsd etc.
      */
-    pspec = g_param_spec_string("distro",
-                                "Distro",
-                                _("Generic Distro"),
-                                NULL /* default value */,
-                                G_PARAM_READABLE |
-                                G_PARAM_STATIC_STRINGS);
-    g_object_class_install_property(g_klass,
-                                    PROP_DISTRO,
-                                    pspec);
+    properties[PROP_DISTRO] = g_param_spec_string("distro",
+                                                  "Distro",
+                                                  _("Generic Distro"),
+                                                  NULL /* default value */,
+                                                  G_PARAM_READABLE |
+                                                  G_PARAM_STATIC_STRINGS);
 
     /**
      * OsinfoOs:kernel-url-argument:
@@ -185,21 +178,32 @@ osinfo_os_class_init(OsinfoOsClass *klass)
      * The argument to be passed to kernel command line when performing a
      * tree based installation of this OS.
      */
-    pspec = g_param_spec_string("kernel-url-argument",
-                                "KernelURLArgument",
-                                _("Kernel URL Argument"),
-                                NULL /* default value */,
-                                G_PARAM_READABLE |
-                                G_PARAM_STATIC_STRINGS);
-    g_object_class_install_property(g_klass,
-                                    PROP_KERNEL_URL_ARGUMENT,
-                                    pspec);
+    properties[PROP_KERNEL_URL_ARGUMENT] = g_param_spec_string("kernel-url-argument",
+                                                               "KernelURLArgument",
+                                                               _("Kernel URL Argument"),
+                                                               NULL /* default value */,
+                                                               G_PARAM_READABLE |
+                                                               G_PARAM_STATIC_STRINGS);
+
+    /**
+     * OsinfoOs:cloud-image-username:
+     *
+     * The username to be passed to the cloud-init program.
+     */
+    properties[PROP_CLOUD_IMAGE_USERNAME] = g_param_spec_string("cloud-image-username",
+                                                                "CloudImageUsername",
+                                                                _("Cloud image username"),
+                                                                NULL /* default value */,
+                                                                G_PARAM_READABLE |
+                                                                G_PARAM_STATIC_STRINGS);
+
+    g_object_class_install_properties(g_klass, LAST_PROP, properties);
 }
 
 static void
 osinfo_os_init(OsinfoOs *os)
 {
-    os->priv = OSINFO_OS_GET_PRIVATE(os);
+    os->priv = osinfo_os_get_instance_private(os);
 
     os->priv->deviceLinks = NULL;
     os->priv->firmwares = osinfo_firmwarelist_new();
@@ -260,12 +264,13 @@ osinfo_os_get_devices_internal(OsinfoOs *os,
                                OsinfoFilter *filter,
                                gboolean include_unsupported)
 {
+    OsinfoDeviceList *newList;
+    GList *tmp = NULL;
+
     g_return_val_if_fail(OSINFO_IS_OS(os), NULL);
     g_return_val_if_fail(!filter || OSINFO_IS_FILTER(filter), NULL);
 
-    OsinfoDeviceList *newList = osinfo_devicelist_new();
-    GList *tmp = NULL;
-
+    newList = osinfo_devicelist_new();
     tmp = os->priv->deviceLinks;
 
     while (tmp) {
@@ -438,12 +443,13 @@ osinfo_os_get_device_links_internal(OsinfoOs *os,
                                     OsinfoFilter *filter,
                                     gboolean include_unsupported)
 {
+    OsinfoDeviceLinkList *newList;
+    GList *tmp = NULL;
+
     g_return_val_if_fail(OSINFO_IS_OS(os), NULL);
     g_return_val_if_fail(!filter || OSINFO_IS_FILTER(filter), NULL);
 
-    OsinfoDeviceLinkList *newList = osinfo_devicelinklist_new();
-    GList *tmp = NULL;
-
+    newList = osinfo_devicelinklist_new();
     tmp = os->priv->deviceLinks;
 
     while (tmp) {
@@ -574,11 +580,12 @@ OsinfoDeviceLinkList *osinfo_os_get_all_device_links(OsinfoOs *os, OsinfoFilter
  */
 OsinfoDeviceLink *osinfo_os_add_device(OsinfoOs *os, OsinfoDevice *dev)
 {
+    OsinfoDeviceLink *devlink;
+
     g_return_val_if_fail(OSINFO_IS_OS(os), NULL);
     g_return_val_if_fail(OSINFO_IS_DEVICE(dev), NULL);
 
-    OsinfoDeviceLink *devlink = osinfo_devicelink_new(dev);
-
+    devlink = osinfo_devicelink_new(dev);
     os->priv->deviceLinks = g_list_append(os->priv->deviceLinks, devlink);
 
     return devlink;
@@ -647,9 +654,11 @@ int osinfo_os_get_release_status(OsinfoOs *os)
  */
 OsinfoMediaList *osinfo_os_get_media_list(OsinfoOs *os)
 {
+    OsinfoMediaList *newList;
+
     g_return_val_if_fail(OSINFO_IS_OS(os), NULL);
 
-    OsinfoMediaList *newList = osinfo_medialist_new();
+    newList = osinfo_medialist_new();
 
     osinfo_list_add_all(OSINFO_LIST(newList), OSINFO_LIST(os->priv->medias));
 
@@ -682,10 +691,11 @@ void osinfo_os_add_media(OsinfoOs *os, OsinfoMedia *media)
  */
 OsinfoTreeList *osinfo_os_get_tree_list(OsinfoOs *os)
 {
+    OsinfoTreeList *newList;
+
     g_return_val_if_fail(OSINFO_IS_OS(os), NULL);
 
-    OsinfoTreeList *newList = osinfo_treelist_new();
-
+    newList = osinfo_treelist_new();
     osinfo_list_add_all(OSINFO_LIST(newList), OSINFO_LIST(os->priv->trees));
 
     return newList;
@@ -719,9 +729,11 @@ void osinfo_os_add_tree(OsinfoOs *os, OsinfoTree *tree)
  */
 OsinfoImageList *osinfo_os_get_image_list(OsinfoOs *os)
 {
+    OsinfoImageList *newList;
+
     g_return_val_if_fail(OSINFO_IS_OS(os), NULL);
 
-    OsinfoImageList *newList = osinfo_imagelist_new();
+    newList = osinfo_imagelist_new();
 
     osinfo_list_add_all(OSINFO_LIST(newList), OSINFO_LIST(os->priv->images));
 
@@ -758,9 +770,11 @@ void osinfo_os_add_image(OsinfoOs *os, OsinfoImage *image)
  */
 OsinfoOsVariantList *osinfo_os_get_variant_list(OsinfoOs *os)
 {
+    OsinfoOsVariantList *newList;
+
     g_return_val_if_fail(OSINFO_IS_OS(os), NULL);
 
-    OsinfoOsVariantList *newList = osinfo_os_variantlist_new();
+    newList = osinfo_os_variantlist_new();
 
     osinfo_list_add_all(OSINFO_LIST(newList), OSINFO_LIST(os->priv->variants));
 
@@ -896,9 +910,11 @@ osinfo_os_get_resources_internal(OsinfoOs *os,
 static OsinfoResourcesList *
 osinfo_os_get_minimum_resources_without_inheritance(OsinfoOs *os)
 {
+    OsinfoResourcesList *newList;
+
     g_return_val_if_fail(OSINFO_IS_OS(os), NULL);
 
-    OsinfoResourcesList *newList = osinfo_resourceslist_new();
+    newList = osinfo_resourceslist_new();
 
     osinfo_list_add_all(OSINFO_LIST(newList), OSINFO_LIST(os->priv->minimum));
 
@@ -932,9 +948,11 @@ OsinfoResourcesList *osinfo_os_get_minimum_resources(OsinfoOs *os)
 static OsinfoResourcesList *
 osinfo_os_get_maximum_resources_without_inheritance(OsinfoOs *os)
 {
+    OsinfoResourcesList *newList;
+
     g_return_val_if_fail(OSINFO_IS_OS(os), NULL);
 
-    OsinfoResourcesList *newList = osinfo_resourceslist_new();
+    newList = osinfo_resourceslist_new();
 
     osinfo_list_add_all(OSINFO_LIST(newList),
                         OSINFO_LIST(os->priv->maximum));
@@ -971,9 +989,11 @@ OsinfoResourcesList *osinfo_os_get_maximum_resources(OsinfoOs *os)
 static OsinfoResourcesList *
 osinfo_os_get_recommended_resources_without_inheritance(OsinfoOs *os)
 {
+    OsinfoResourcesList *newList;
+
     g_return_val_if_fail(OSINFO_IS_OS(os), NULL);
 
-    OsinfoResourcesList *newList = osinfo_resourceslist_new();
+    newList = osinfo_resourceslist_new();
 
     osinfo_list_add_all(OSINFO_LIST(newList),
                         OSINFO_LIST(os->priv->recommended));
@@ -1009,9 +1029,11 @@ OsinfoResourcesList *osinfo_os_get_recommended_resources(OsinfoOs *os)
 static OsinfoResourcesList *
 osinfo_os_get_network_install_resources_without_inheritance(OsinfoOs *os)
 {
+    OsinfoResourcesList *newList;
+
     g_return_val_if_fail(OSINFO_IS_OS(os), NULL);
 
-    OsinfoResourcesList *newList = osinfo_resourceslist_new();
+    newList = osinfo_resourceslist_new();
 
     osinfo_list_add_all(OSINFO_LIST(newList),
                         OSINFO_LIST(os->priv->network_install));
@@ -1199,8 +1221,8 @@ OsinfoDeviceDriverList *osinfo_os_get_device_drivers(OsinfoOs *os)
 static gint osinfo_device_drivers_sort_by_priority(gconstpointer a,
                                                    gconstpointer b)
 {
-    OsinfoDeviceDriver *adriver = OSINFO_DEVICE_DRIVER(a);
-    OsinfoDeviceDriver *bdriver = OSINFO_DEVICE_DRIVER(b);
+    OsinfoDeviceDriver *adriver = OSINFO_DEVICE_DRIVER((gpointer) a);
+    OsinfoDeviceDriver *bdriver = OSINFO_DEVICE_DRIVER((gpointer) b);
 
     return osinfo_device_driver_get_priority(bdriver) - osinfo_device_driver_get_priority(adriver);
 }
@@ -1304,6 +1326,50 @@ const gchar *osinfo_os_get_kernel_url_argument(OsinfoOs *os)
     return foreach_data.kernel_url_arg;
 }
 
+struct GetImageUsernameData {
+    const gchar *username;
+};
+
+static void get_cloud_image_username_cb(OsinfoProduct *product, gpointer user_data)
+{
+    OsinfoOs *os = OSINFO_OS(product);
+    struct GetImageUsernameData *foreach_data = user_data;
+
+    g_return_if_fail(OSINFO_IS_OS(os));
+
+    if (foreach_data->username != NULL)
+        return;
+
+    foreach_data->username =
+            osinfo_entity_get_param_value(OSINFO_ENTITY(os),
+                                          OSINFO_OS_PROP_CLOUD_IMAGE_USERNAME);
+}
+
+/**
+ * osinfo_os_get_cloud_image_username:
+ * @os: an operating system
+ *
+ * Gets the username expected to be passed to the cloud image when performing
+ * installation.
+ *
+ * Returns: (transfer none): ther username, if present. Otherwise, NULL.
+ */
+const gchar *osinfo_os_get_cloud_image_username(OsinfoOs *os)
+{
+    struct GetImageUsernameData foreach_data = {
+        .username = NULL
+    };
+    g_return_val_if_fail(OSINFO_IS_OS(os), NULL);
+
+    osinfo_product_foreach_related(OSINFO_PRODUCT(os),
+                                   OSINFO_PRODUCT_FOREACH_FLAG_DERIVES_FROM |
+                                   OSINFO_PRODUCT_FOREACH_FLAG_CLONES,
+                                   get_cloud_image_username_cb,
+                                   &foreach_data);
+
+    return foreach_data.username;
+}
+
 struct GetAllFirmwaresData {
     OsinfoFilter *filter;
     OsinfoFilter *unsupported_filter;
@@ -1425,20 +1491,22 @@ static void get_all_firmwares_cb(OsinfoProduct *product, gpointer user_data)
  * Get all firmwares matching a given filter
  *
  * Returns: (transfer full): A list of firmwares
+ *
+ * Since: 1.7.0
  */
 OsinfoFirmwareList *osinfo_os_get_firmware_list(OsinfoOs *os, OsinfoFilter *filter)
 {
+    struct GetAllFirmwaresData foreach_data;
+
     g_return_val_if_fail(OSINFO_IS_OS(os), NULL);
     g_return_val_if_fail(!filter || OSINFO_IS_FILTER(filter), NULL);
 
-    struct GetAllFirmwaresData foreach_data = {
-        .filter = filter,
-        .unsupported_filter = NULL,
-        .firmwares = osinfo_firmwarelist_new(),
-        .unsupported_firmwares = osinfo_firmwarelist_new()
-    };
-
+    foreach_data.filter = filter;
+    foreach_data.unsupported_filter = NULL;
+    foreach_data.firmwares = osinfo_firmwarelist_new();
+    foreach_data.unsupported_firmwares = osinfo_firmwarelist_new();
     foreach_data.unsupported_filter = osinfo_filter_new();
+
     osinfo_filter_add_constraint(foreach_data.unsupported_filter,
                                  OSINFO_FIRMWARE_PROP_SUPPORTED,
                                  "false");
