@@ -1,7 +1,7 @@
 /*
  * libosinfo: An installation tree for a (guest) OS
  *
- * Copyright (C) 2009-2012, 2014 Red Hat, Inc.
+ * Copyright (C) 2009-2020 Red Hat, Inc.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -16,11 +16,6 @@
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library. If not, see
  * <http://www.gnu.org/licenses/>.
- *
- * Authors:
- *   Zeeshan Ali <zeenix@redhat.com>
- *   Arjun Roy <arroy@redhat.com>
- *   Daniel P. Berrange <berrange@redhat.com>
  */
 
 #include <osinfo/osinfo.h>
@@ -89,13 +84,6 @@ osinfo_tree_error_quark(void)
     return quark;
 }
 
-G_DEFINE_TYPE(OsinfoTree, osinfo_tree, OSINFO_TYPE_ENTITY);
-
-#define OSINFO_TREE_GET_PRIVATE(obj)                    \
-    (G_TYPE_INSTANCE_GET_PRIVATE((obj),                \
-                                  OSINFO_TYPE_TREE,     \
-                                  OsinfoTreePrivate))
-
 /**
  * SECTION:osinfo_tree
  * @short_description: An installation tree for a (guest) OS
@@ -110,6 +98,8 @@ struct _OsinfoTreePrivate
     GWeakRef os;
 };
 
+G_DEFINE_TYPE_WITH_PRIVATE(OsinfoTree, osinfo_tree, OSINFO_TYPE_ENTITY);
+
 enum {
     PROP_0,
 
@@ -124,7 +114,10 @@ enum {
     PROP_BOOT_ISO_PATH,
     PROP_HAS_TREEINFO,
     PROP_OS,
+
+    LAST_PROP
 };
+static GParamSpec *properties[LAST_PROP];
 
 static void
 osinfo_tree_get_property(GObject *object,
@@ -298,178 +291,166 @@ static void
 osinfo_tree_class_init(OsinfoTreeClass *klass)
 {
     GObjectClass *g_klass = G_OBJECT_CLASS(klass);
-    GParamSpec *pspec;
 
     g_klass->dispose = osinfo_tree_dispose;
     g_klass->finalize = osinfo_tree_finalize;
     g_klass->get_property = osinfo_tree_get_property;
     g_klass->set_property = osinfo_tree_set_property;
-    g_type_class_add_private(klass, sizeof(OsinfoTreePrivate));
 
     /**
      * OsinfoTree:architecture:
      *
      * The target hardware architecture of this tree.
      */
-    pspec = g_param_spec_string("architecture",
-                                "ARCHITECTURE",
-                                _("CPU Architecture"),
-                                NULL /* default value */,
-                                G_PARAM_READWRITE |
-                                G_PARAM_STATIC_STRINGS);
-    g_object_class_install_property(g_klass, PROP_ARCHITECTURE, pspec);
+    properties[PROP_ARCHITECTURE] = g_param_spec_string("architecture",
+                                                        "ARCHITECTURE",
+                                                        _("CPU Architecture"),
+                                                        NULL /* default value */,
+                                                        G_PARAM_READWRITE |
+                                                        G_PARAM_STATIC_STRINGS);
 
     /**
      * OsinfoTree:url:
      *
      * The URL to this tree.
      */
-    pspec = g_param_spec_string("url",
-                                "URL",
-                                _("The URL to this tree"),
-                                NULL /* default value */,
-                                G_PARAM_READWRITE |
-                                G_PARAM_STATIC_STRINGS);
-    g_object_class_install_property(g_klass, PROP_URL, pspec);
+    properties[PROP_URL] = g_param_spec_string("url",
+                                               "URL",
+                                               _("The URL to this tree"),
+                                               NULL /* default value */,
+                                               G_PARAM_READWRITE |
+                                               G_PARAM_STATIC_STRINGS);
 
     /**
      * OsinfoTree:kernel-path:
      *
      * The path to the kernel image in the install tree.
      */
-    pspec = g_param_spec_string("kernel-path",
-                                "KernelPath",
-                                _("The path to the kernel image"),
-                                NULL /* default value */,
-                                G_PARAM_READWRITE |
-                                G_PARAM_STATIC_STRINGS);
-    g_object_class_install_property(g_klass, PROP_KERNEL_PATH, pspec);
+    properties[PROP_KERNEL_PATH] = g_param_spec_string("kernel-path",
+                                                       "KernelPath",
+                                                       _("The path to the kernel image"),
+                                                       NULL /* default value */,
+                                                       G_PARAM_READWRITE |
+                                                       G_PARAM_STATIC_STRINGS);
 
     /**
      * OsinfoTree:initrd-path:
      *
      * The path to the initrd image in the install tree.
      */
-    pspec = g_param_spec_string("initrd-path",
-                                "InitrdPath",
-                                _("The path to the inirtd image"),
-                                NULL /* default value */,
-                                G_PARAM_READWRITE |
-                                G_PARAM_STATIC_STRINGS);
-    g_object_class_install_property(g_klass, PROP_INITRD_PATH, pspec);
+    properties[PROP_INITRD_PATH] = g_param_spec_string("initrd-path",
+                                                       "InitrdPath",
+                                                       _("The path to the initrd image"),
+                                                       NULL /* default value */,
+                                                       G_PARAM_READWRITE |
+                                                       G_PARAM_STATIC_STRINGS);
 
     /**
      * OsinfoTree:boot-iso-path:
      *
      * The path to the boot ISO in the install tree
      */
-    pspec = g_param_spec_string("boot-iso-path",
-                                "BootISOPath",
-                                _("The path to the bootable ISO image"),
-                                NULL /* default value */,
-                                G_PARAM_READWRITE |
-                                G_PARAM_STATIC_STRINGS);
-    g_object_class_install_property(g_klass, PROP_BOOT_ISO_PATH, pspec);
+    properties[PROP_BOOT_ISO_PATH] = g_param_spec_string("boot-iso-path",
+                                                         "BootISOPath",
+                                                         _("The path to the bootable ISO image"),
+                                                         NULL /* default value */,
+                                                         G_PARAM_READWRITE |
+                                                         G_PARAM_STATIC_STRINGS);
 
     /**
      * OsinfoTree:has-treeinfo
      *
      * Whether the tree has treeinfo or not
      */
-    pspec = g_param_spec_boolean("has-treeinfo",
-                                 "HasTreeinfo",
-                                 _("Whether the tree has treeinfo"),
-                                 FALSE /* default value */,
-                                 G_PARAM_READWRITE |
-                                 G_PARAM_STATIC_STRINGS);
-    g_object_class_install_property(g_klass, PROP_HAS_TREEINFO, pspec);
+    properties[PROP_HAS_TREEINFO] = g_param_spec_boolean("has-treeinfo",
+                                                         "HasTreeinfo",
+                                                         _("Whether the tree has treeinfo"),
+                                                         FALSE /* default value */,
+                                                         G_PARAM_READWRITE |
+                                                         G_PARAM_STATIC_STRINGS);
 
     /**
      * OsinfoTree:treeinfo-family
      *
      * The treeinfo family
      */
-    pspec = g_param_spec_string("treeinfo-family",
-                                "TreeInfoFamily",
-                                _("The treeinfo family"),
-                                NULL /* default value */,
-                                G_PARAM_READWRITE |
-                                G_PARAM_STATIC_STRINGS);
-    g_object_class_install_property(g_klass, PROP_TREEINFO_FAMILY, pspec);
+    properties[PROP_TREEINFO_FAMILY] = g_param_spec_string("treeinfo-family",
+                                                           "TreeInfoFamily",
+                                                           _("The treeinfo family"),
+                                                           NULL /* default value */,
+                                                           G_PARAM_READWRITE |
+                                                           G_PARAM_STATIC_STRINGS);
 
     /**
      * OsinfoTree:treeinfo-variant
      *
      * The treeinfo variant
      */
-    pspec = g_param_spec_string("treeinfo-variant",
-                                "TreeInfoVariant",
-                                _("The treeinfo variant"),
-                                NULL /* default value */,
-                                G_PARAM_READWRITE |
-                                G_PARAM_STATIC_STRINGS);
-    g_object_class_install_property(g_klass, PROP_TREEINFO_FAMILY, pspec);
+    properties[PROP_TREEINFO_VARIANT] = g_param_spec_string("treeinfo-variant",
+                                                            "TreeInfoVariant",
+                                                            _("The treeinfo variant"),
+                                                            NULL /* default value */,
+                                                            G_PARAM_READWRITE |
+                                                            G_PARAM_STATIC_STRINGS);
 
     /**
      * OsinfoTree:treeinfo-version
      *
      * The treeinfo version
      */
-    pspec = g_param_spec_string("treeinfo-version",
-                                "TreeInfoVersion",
-                                _("The treeinfo version"),
-                                NULL /* default value */,
-                                G_PARAM_READWRITE |
-                                G_PARAM_STATIC_STRINGS);
-    g_object_class_install_property(g_klass, PROP_TREEINFO_FAMILY, pspec);
+    properties[PROP_TREEINFO_VERSION] = g_param_spec_string("treeinfo-version",
+                                                            "TreeInfoVersion",
+                                                            _("The treeinfo version"),
+                                                            NULL /* default value */,
+                                                            G_PARAM_READWRITE |
+                                                            G_PARAM_STATIC_STRINGS);
 
     /**
      * OsinfoTree:treeinfo-arch
      *
      * The treeinfo arch
      */
-    pspec = g_param_spec_string("treeinfo-arch",
-                                "TreeInfoArch",
-                                _("The treeinfo architecture"),
-                                NULL /* default value */,
-                                G_PARAM_READWRITE |
-                                G_PARAM_STATIC_STRINGS);
-    g_object_class_install_property(g_klass, PROP_TREEINFO_FAMILY, pspec);
+    properties[PROP_TREEINFO_ARCH] = g_param_spec_string("treeinfo-arch",
+                                                         "TreeInfoArch",
+                                                         _("The treeinfo architecture"),
+                                                         NULL /* default value */,
+                                                         G_PARAM_READWRITE |
+                                                         G_PARAM_STATIC_STRINGS);
 
     /**
      * OsinfoTree:os:
      *
      * Os information for the current tree. For tree stored in an
-     * #OsinfoDB, it will be filled when the database is loaded, otherwise
+     * #OsinfoDb, it will be filled when the database is loaded, otherwise
      * the property will be filled after a successful call to
      * osinfo_db_identify_tree().
      */
-    pspec = g_param_spec_object("os",
-                                "Os",
-                                _("Information about the operating system on this tree"),
-                                OSINFO_TYPE_OS,
-                                G_PARAM_READWRITE |
-                                G_PARAM_STATIC_STRINGS);
-    g_object_class_install_property(g_klass, PROP_OS, pspec);
+    properties[PROP_OS] = g_param_spec_object("os",
+                                              "Os",
+                                              _("Information about the operating system on this tree"),
+                                              OSINFO_TYPE_OS,
+                                              G_PARAM_READWRITE |
+                                              G_PARAM_STATIC_STRINGS);
+
+    g_object_class_install_properties(g_klass, LAST_PROP, properties);
 }
 
 static void
 osinfo_tree_init(OsinfoTree *tree)
 {
-    tree->priv = OSINFO_TREE_GET_PRIVATE(tree);
+    tree->priv = osinfo_tree_get_instance_private(tree);
 
     g_weak_ref_init(&tree->priv->os, NULL);
 }
 
 /**
  * osinfo_tree_new:
- *
  * @id: the id of the tree to be created
  * @architecture: the architecture of the tree to be created
  *
  * Create a new tree entity
  *
- * Returns: (trasfer full): A tree entity
+ * Returns: (transfer full): A tree entity
  *
  * Since: 0.1.0
  */
@@ -841,7 +822,9 @@ osinfo_tree_create_from_location_async_helper(CreateFromLocationAsyncData *data,
 
     if (requires_soup) {
         if (data->session == NULL)
-            data->session = soup_session_new();
+            data->session = soup_session_new_with_options(
+                    SOUP_SESSION_USER_AGENT, "Wget/1.0",
+                    NULL);
 
         g_clear_object(&data->message);
         data->message = soup_message_new("GET", location);
@@ -941,6 +924,8 @@ const gchar *osinfo_tree_get_architecture(OsinfoTree *tree)
  * The URL to the @tree
  *
  * Returns: (transfer none): the URL, or NULL
+ *
+ * Since: 0.1.0
  */
 const gchar *osinfo_tree_get_url(OsinfoTree *tree)
 {
