@@ -13,9 +13,6 @@
  *
  * You should have received a copy of the GNU General Public License along
  * with this program. If not, see <http://www.gnu.org/licenses/>
- *
- * Authors:
- *   Daniel P. Berrange <berrange@redhat.com>
  */
 
 #include <osinfo/osinfo.h>
@@ -40,13 +37,16 @@ test_devices(void)
     OsinfoOs *os = osinfo_os_new("awesome");
     OsinfoDevice *dev1 = osinfo_device_new("e1000");
     OsinfoDevice *dev2 = osinfo_device_new("rtl8139");
+    OsinfoDeviceLink *link1;
+    OsinfoDeviceLink *link2;
+    OsinfoDeviceList *devices;
 
-    OsinfoDeviceLink *link1 = osinfo_os_add_device(os, dev1);
+    link1 = osinfo_os_add_device(os, dev1);
     osinfo_entity_add_param(OSINFO_ENTITY(link1), "device", "pci-e1000");
-    OsinfoDeviceLink *link2 = osinfo_os_add_device(os, dev2);
+    link2 = osinfo_os_add_device(os, dev2);
     osinfo_entity_add_param(OSINFO_ENTITY(link2), "device", "pci-8139");
 
-    OsinfoDeviceList *devices = osinfo_os_get_devices(os, NULL);
+    devices = osinfo_os_get_devices(os, NULL);
 
     g_assert_cmpint(osinfo_list_get_length(OSINFO_LIST(devices)), ==, 2);
     g_assert_true(osinfo_list_get_nth(OSINFO_LIST(devices), 0) == OSINFO_ENTITY(dev1));
@@ -117,15 +117,6 @@ test_loader(void)
     g_assert_cmpstr(str, ==, "test4");
     g_assert_cmpint(osinfo_os_get_release_status(os), ==, OSINFO_RELEASE_STATUS_SNAPSHOT);
 
-    os = osinfo_db_get_os(db, "http://libosinfo.org/test/os/test5");
-    g_assert_nonnull(os);
-    str = osinfo_product_get_short_id(OSINFO_PRODUCT(os));
-    g_assert_cmpstr(str, ==, "test5");
-    /* 'test5' OS intentionnally contains an invalid release status */
-    g_test_expect_message(NULL, G_LOG_LEVEL_CRITICAL,
-                          "*(osinfo_entity_get_param_value_enum): should not be reached*");
-    g_assert_cmpint(osinfo_os_get_release_status(os), ==, OSINFO_RELEASE_STATUS_RELEASED);
-
     os = osinfo_db_get_os(db, "http://fedoraproject.org/fedora/16");
     g_assert_nonnull(os);
     str = osinfo_product_get_short_id(OSINFO_PRODUCT(os));
@@ -162,21 +153,25 @@ test_devices_filter(void)
     OsinfoDevice *dev1 = osinfo_device_new("e1000");
     OsinfoDevice *dev2 = osinfo_device_new("sb16");
     OsinfoFilter *filter = osinfo_filter_new();
+    OsinfoDeviceLink *link1;
+    OsinfoDeviceLink *link2;
+    OsinfoDeviceList *devices;
+    OsinfoEntity *ent;
 
     osinfo_entity_add_param(OSINFO_ENTITY(dev1), "class", "network");
     osinfo_entity_add_param(OSINFO_ENTITY(dev2), "class", "audio");
 
-    OsinfoDeviceLink *link1 = osinfo_os_add_device(os, dev1);
+    link1 = osinfo_os_add_device(os, dev1);
     osinfo_entity_add_param(OSINFO_ENTITY(link1), "driver", "pci-e1000");
-    OsinfoDeviceLink *link2 = osinfo_os_add_device(os, dev2);
+    link2 = osinfo_os_add_device(os, dev2);
     osinfo_entity_add_param(OSINFO_ENTITY(link2), "driver", "isa-sb16");
 
     osinfo_filter_add_constraint(filter, "class", "network");
 
-    OsinfoDeviceList *devices = osinfo_os_get_devices(os, filter);
+    devices = osinfo_os_get_devices(os, filter);
 
     g_assert_cmpint(osinfo_list_get_length(OSINFO_LIST(devices)), ==, 1);
-    OsinfoEntity *ent = osinfo_list_get_nth(OSINFO_LIST(devices), 0);
+    ent = osinfo_list_get_nth(OSINFO_LIST(devices), 0);
     g_assert_true(OSINFO_IS_DEVICE(ent));
     g_assert_true(OSINFO_DEVICE(ent) == dev1);
 
@@ -195,13 +190,15 @@ test_device_driver(void)
     OsinfoDevice *dev1 = osinfo_device_new("e1000");
     OsinfoDevice *dev2 = osinfo_device_new("rtl8139");
     OsinfoFilter *filter = osinfo_filter_new();
+    OsinfoDeviceLink *link1;
+    OsinfoDeviceLink *link2;
 
     osinfo_entity_add_param(OSINFO_ENTITY(dev1), "class", "network");
     osinfo_entity_add_param(OSINFO_ENTITY(dev2), "class", "network");
 
-    OsinfoDeviceLink *link1 = osinfo_os_add_device(os, dev1);
+    link1 = osinfo_os_add_device(os, dev1);
     osinfo_entity_add_param(OSINFO_ENTITY(link1), "driver", "pci-e1000");
-    OsinfoDeviceLink *link2 = osinfo_os_add_device(os, dev2);
+    link2 = osinfo_os_add_device(os, dev2);
     osinfo_entity_add_param(OSINFO_ENTITY(link2), "driver", "pci-8139");
 
     osinfo_filter_add_constraint(filter, "class", "network");
@@ -852,6 +849,41 @@ test_firmwares_inheritance(void)
     g_object_unref(db);
 }
 
+static void
+test_cloud_image_username_arg(void)
+{
+    OsinfoLoader *loader;
+    OsinfoDb *db;
+    OsinfoOs *os;
+    GError *error = NULL;
+    const char *str;
+
+    loader = osinfo_loader_new();
+    osinfo_loader_process_path(loader, SRCDIR "/tests/dbdata", &error);
+    g_assert_no_error(error);
+    db = osinfo_loader_get_db(loader);
+
+    g_debug("Testing http://libosinfo.org/test/os/cloud-image-username-arg1\n");
+    os = osinfo_db_get_os(db, "http://libosinfo.org/test/os/cloud-image-username-arg1");
+    g_assert_nonnull(os);
+    str = osinfo_os_get_cloud_image_username(os);
+    g_assert_cmpstr(str, ==, "cloud");
+
+    g_debug("Testing http://libosinfo.org/test/os/cloud-image-username-arg2\n");
+    os = osinfo_db_get_os(db, "http://libosinfo.org/test/os/cloud-image-username-arg2");
+    g_assert_nonnull(os);
+    str = osinfo_os_get_cloud_image_username(os);
+    g_assert_cmpstr(str, ==, "cloud");
+
+    g_debug("Testing http://libosinfo.org/test/os/cloud-image-username-arg3\n");
+    os = osinfo_db_get_os(db, "http://libosinfo.org/test/os/cloud-image-username-arg3");
+    g_assert_nonnull(os);
+    str = osinfo_os_get_cloud_image_username(os);
+    g_assert_cmpstr(str, ==, "new.cloud");
+
+    g_object_unref(loader);
+}
+
 int
 main(int argc, char *argv[])
 {
@@ -876,6 +908,7 @@ main(int argc, char *argv[])
     g_test_add_func("/os/mulitple_short_ids", test_multiple_short_ids);
     g_test_add_func("/os/kernel_url_arg", test_kernel_url_arg);
     g_test_add_func("/os/firmwares/inheritance", test_firmwares_inheritance);
+    g_test_add_func("/os/cloud_image_username_arg", test_cloud_image_username_arg);
 
     /* Upfront so we don't confuse valgrind */
     osinfo_platform_get_type();
